# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RBBR_METADATA = Metadata(
    id="6f8461b7fae6d16cb41c5377c9a0a117f94c76da.boutiques",
    name="rbbr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RbbrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rbbr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_reg_file: OutputPathType | None
    """Output registration file"""
    output_lta_file: OutputPathType | None
    """Output LTA file"""
    output_template_file: OutputPathType | None
    """Saved template output file"""


def rbbr(
    moving_image: str,
    subject: str | None = None,
    t2_contrast: bool = False,
    init_header: bool = False,
    cost_threshold: float | None = None,
    gtm_synthesize: str | None = None,
    tt_reduce: bool = False,
    iterations: float | None = None,
    output_reg: str | None = None,
    output_lta: str | None = None,
    left_hemi: bool = False,
    right_hemi: bool = False,
    gm_proj_frac: float | None = None,
    gm_proj_abs: float | None = None,
    wm_proj_abs: float | None = None,
    frame_no: float | None = None,
    output_template: str | None = None,
    no_merge: bool = False,
    runner: Runner | None = None,
) -> RbbrOutputs:
    """
    Robust version of bbregister.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        moving_image: Input moving image.
        subject: FreeSurfer subject (not needed with --init-reg).
        t2_contrast: Use T2 tissue contrast.
        init_header: Initialize using header.
        cost_threshold: Cost threshold to define outlier.
        gtm_synthesize: Use GTM to synthesize.
        tt_reduce: Reduce GTM Seg to tissue types for faster processing.
        iterations: Number of iterations.
        output_reg: Output registration file.
        output_lta: Output LTA file.
        left_hemi: Only use left hemisphere.
        right_hemi: Only use right hemisphere.
        gm_proj_frac: GM projection fraction.
        gm_proj_abs: GM projection absolute.
        wm_proj_abs: WM projection absolute.
        frame_no: Use 0-based frame number as template.
        output_template: Save template as an output.
        no_merge: Do not merge GTM Ids.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RbbrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RBBR_METADATA)
    cargs = []
    cargs.append("rbbr")
    if subject is not None:
        cargs.extend([
            "--s",
            subject
        ])
    cargs.extend([
        "--mov",
        moving_image
    ])
    if t2_contrast:
        cargs.append("--t2")
    if init_header:
        cargs.append("--init-header")
    if cost_threshold is not None:
        cargs.extend([
            "--cthresh",
            str(cost_threshold)
        ])
    if gtm_synthesize is not None:
        cargs.extend([
            "--gtm",
            gtm_synthesize
        ])
    if tt_reduce:
        cargs.append("--tt-reduce")
    if iterations is not None:
        cargs.extend([
            "--iters",
            str(iterations)
        ])
    if output_reg is not None:
        cargs.extend([
            "--reg",
            output_reg
        ])
    if output_lta is not None:
        cargs.extend([
            "--lta",
            output_lta
        ])
    if left_hemi:
        cargs.append("--lh-only")
    if right_hemi:
        cargs.append("--rh-only")
    if gm_proj_frac is not None:
        cargs.extend([
            "--gm-proj-frac",
            str(gm_proj_frac)
        ])
    if gm_proj_abs is not None:
        cargs.extend([
            "--gm-proj-abs",
            str(gm_proj_abs)
        ])
    if wm_proj_abs is not None:
        cargs.extend([
            "--wm-proj-abs",
            str(wm_proj_abs)
        ])
    if frame_no is not None:
        cargs.extend([
            "--frame",
            str(frame_no)
        ])
    if output_template is not None:
        cargs.extend([
            "--template",
            output_template
        ])
    if no_merge:
        cargs.append("--no-merge")
    ret = RbbrOutputs(
        root=execution.output_file("."),
        output_reg_file=execution.output_file(output_reg) if (output_reg is not None) else None,
        output_lta_file=execution.output_file(output_lta) if (output_lta is not None) else None,
        output_template_file=execution.output_file(output_template) if (output_template is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RBBR_METADATA",
    "RbbrOutputs",
    "rbbr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHARM_RECO_METADATA = Metadata(
    id="33f63f74ec6a7870069eec599fbb3c35bec65ba8.boutiques",
    name="SpharmReco",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SpharmRecoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spharm_reco(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def spharm_reco(
    input_surface: str,
    decomposition_order: float,
    bases_prefix: str,
    coefficients: list[InputPathType],
    output_prefix: str | None = None,
    output_surface: list[str] | None = None,
    debug: float | None = None,
    smoothing: float | None = None,
    runner: Runner | None = None,
) -> SpharmRecoOutputs:
    """
    Spherical Harmonics Reconstruction from a set of harmonics and their
    corresponding coefficients.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_surface: Surface that provides the topology of the mesh (nodes'\
            connections). TYPE specifies the input surface type.
        decomposition_order: Decomposition order.
        bases_prefix: Prefix of files containing the bases functions (spherical\
            harmonics). These files are generated with SpharmDeco.
        coefficients: Coefficients files used to recompose data columns.\
            Multiple coefficient files can be specified by repeating the option.
        output_prefix: Write out the reconstructed data into dataset PREFIX.\
            The output contains N columns; one for each COEF file.
        output_surface: Write out a new surface with reconstructed coordinates.\
            Requires N to be a multiple of 3.
        debug: Debug levels (1-3).
        smoothing: Smoothing parameter (0 .. 0.001) weighing the contribution\
            of higher order harmonics.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpharmRecoOutputs`).
    """
    if not (1 <= len(coefficients)): 
        raise ValueError(f"Length of 'coefficients' must be greater than 1 but was {len(coefficients)}")
    if smoothing is not None and not (0 <= smoothing <= 0.001): 
        raise ValueError(f"'smoothing' must be between 0 <= x <= 0.001 but was {smoothing}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHARM_RECO_METADATA)
    cargs = []
    cargs.append("SpharmReco")
    cargs.extend([
        "-i_TYPE",
        input_surface
    ])
    cargs.extend([
        "-l",
        str(decomposition_order)
    ])
    cargs.extend([
        "-bases_prefix",
        bases_prefix
    ])
    cargs.extend([
        "-coef",
        *[execution.input_file(f) for f in coefficients]
    ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if output_surface is not None:
        cargs.extend([
            "-o_TYPE",
            *output_surface
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    if smoothing is not None:
        cargs.extend([
            "-sigma",
            str(smoothing)
        ])
    ret = SpharmRecoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHARM_RECO_METADATA",
    "SpharmRecoOutputs",
    "spharm_reco",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HIAM_REGISTER_METADATA = Metadata(
    id="44d0a11f2a96d3babdb3cdeabdf7fd3e2408cf2f.boutiques",
    name="hiam_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class HiamRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `hiam_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_surface: OutputPathType
    """The output surface after registration."""


def hiam_register(
    input_surface: InputPathType,
    average_surface: InputPathType,
    output_surface: str,
    runner: Runner | None = None,
) -> HiamRegisterOutputs:
    """
    This program registers a surface with an average surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: The input surface to be registered.
        average_surface: The average surface to register against.
        output_surface: The path where the output registered surface will be\
            saved.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HiamRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HIAM_REGISTER_METADATA)
    cargs = []
    cargs.append("hiam_register")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(average_surface))
    cargs.append(output_surface)
    ret = HiamRegisterOutputs(
        root=execution.output_file("."),
        registered_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HIAM_REGISTER_METADATA",
    "HiamRegisterOutputs",
    "hiam_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_CLUST_METADATA = Metadata(
    id="2346425eb197f04f33322dea847636dd74a3b8a3.boutiques",
    name="SurfClust",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfClustOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_clust(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cluster_table: OutputPathType | None
    """Cluster table output"""
    clustered_dataset: OutputPathType | None
    """Clustered version of input dataset"""
    roi_dataset: OutputPathType | None
    """ROI dataset with rank of clusters"""


def surf_clust(
    input_dataset: list[InputPathType],
    rmm: float,
    specfile: InputPathType | None = None,
    input_surface: str | None = None,
    input_surf_name: InputPathType | None = None,
    amm2: float | None = None,
    min_nodes: float | None = None,
    prefix: str | None = None,
    out_clusterdset: bool = False,
    out_roidset: bool = False,
    out_fulllist: bool = False,
    sort_none: bool = False,
    sort_n_nodes: bool = False,
    sort_area: bool = False,
    thresh_col: float | None = None,
    thresh: float | None = None,
    athresh: float | None = None,
    ir_range: list[float] | None = None,
    ex_range: list[float] | None = None,
    prepend_node_index: bool = False,
    update_: float | None = None,
    no_cent: bool = False,
    cent: bool = False,
    novolreg: bool = False,
    noxform: bool = False,
    set_env: str | None = None,
    trace_: bool = False,
    trace_extreme: bool = False,
    no_memory_trace: bool = False,
    yes_memory_trace: bool = False,
    mini_help: bool = False,
    help_: bool = False,
    extreme_help: bool = False,
    view_help: bool = False,
    web_help: bool = False,
    find_help: str | None = None,
    raw_help: bool = False,
    spx_help: bool = False,
    aspx_help: bool = False,
    runner: Runner | None = None,
) -> SurfClustOutputs:
    """
    A program to perform clustering analysis surfaces.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: The input dataset and the index of the datacolumn to use\
            (index 0 for 1st column). Values of 0 indicate inactive nodes.
        rmm: Maximum distance between an activated node and the cluster to\
            which it belongs.
        specfile: The surface spec file.
        input_surface: The input surface name.
        input_surf_name: Full name of the input surface.
        amm2: Minimum area for clusters.
        min_nodes: Minimum nodes for clusters.
        prefix: Prefix for output. Default is the prefix of the input dataset.
        out_clusterdset: Output a clustered version of input dataset.
        out_roidset: Output an ROI dataset with the rank of its cluster.
        out_fulllist: Output a value for all nodes of input surface.
        sort_none: No sorting of ROI clusters.
        sort_n_nodes: Sorting based on number of nodes in cluster.
        sort_area: Sorting based on area of clusters (default).
        thresh_col: Index of thresholding column. Default is column 0.
        thresh: Apply thresholding prior to clustering.
        athresh: Apply absolute thresholding prior to clustering.
        ir_range: Apply thresholding in range. A node n is considered if\
            thresh_col[n] >= R0 && thresh_col[n] <= R1.
        ex_range: Apply thresholding outside of range. A node n is considered\
            if thresh_col[n] < R0 || thresh_col[n] > R1.
        prepend_node_index: Force the output dataset to have node indices in\
            column 0 of output.
        update_: Pacify me when perc of the data have been processed. perc is\
            between 1% and 50%. Default is no update.
        no_cent: Do not find the central nodes.
        cent: Do find the central nodes (default).
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations present in the Surface Volume.
        noxform: Same as -novolreg.
        set_env: Set environment variable ENVname to be ENVvalue. Quotes are\
            necessary.
        trace_: Turns on In/Out debug and Memory tracing.
        trace_extreme: Turns on extreme tracing.
        no_memory_trace: Turn off memory tracing.
        yes_memory_trace: Turn on memory tracing (default).
        mini_help: Mini help, same as -help in many cases.
        help_: The entire help output.
        extreme_help: Extreme help, same as -help in majority of cases.
        view_help: Open help in text editor. AFNI will try to find a GUI editor\
            on your machine. You can control which it should use by setting\
            environment variable AFNI_GUI_EDITOR.
        web_help: Open help in web browser. AFNI will try to find a browser.\
            You can control which it should use by setting environment variable\
            AFNI_GUI_EDITOR.
        find_help: Look for lines in this program's -help output that match\
            (approximately) the given word.
        raw_help: Help string unedited.
        spx_help: Help string in sphinx format, but do not try to autoformat.
        aspx_help: Help string in sphinx format with autoformatting of options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfClustOutputs`).
    """
    if (len(input_dataset) != 2): 
        raise ValueError(f"Length of 'input_dataset' must be 2 but was {len(input_dataset)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_CLUST_METADATA)
    cargs = []
    cargs.append("SurfClust")
    if specfile is not None:
        cargs.extend([
            "-spec",
            execution.input_file(specfile)
        ])
    if input_surface is not None:
        cargs.extend([
            "-surf_A",
            input_surface
        ])
    if input_surf_name is not None:
        cargs.extend([
            "-i",
            execution.input_file(input_surf_name)
        ])
    cargs.extend([
        "-input",
        *[execution.input_file(f) for f in input_dataset]
    ])
    cargs.extend([
        "-rmm",
        str(rmm)
    ])
    if amm2 is not None:
        cargs.extend([
            "-amm2",
            str(amm2)
        ])
    if min_nodes is not None:
        cargs.extend([
            "-n",
            str(min_nodes)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if out_clusterdset:
        cargs.append("-out_clusterdset")
    if out_roidset:
        cargs.append("-out_roidset")
    if out_fulllist:
        cargs.append("-out_fulllist")
    if sort_none:
        cargs.append("-sort_none")
    if sort_n_nodes:
        cargs.append("-sort_n_nodes")
    if sort_area:
        cargs.append("-sort_area")
    if thresh_col is not None:
        cargs.extend([
            "-thresh_col",
            str(thresh_col)
        ])
    if thresh is not None:
        cargs.extend([
            "-thresh",
            str(thresh)
        ])
    if athresh is not None:
        cargs.extend([
            "-athresh",
            str(athresh)
        ])
    if ir_range is not None:
        cargs.extend([
            "-ir_range",
            *map(str, ir_range)
        ])
    if ex_range is not None:
        cargs.extend([
            "-ex_range",
            *map(str, ex_range)
        ])
    if prepend_node_index:
        cargs.append("-prepend_node_index")
    if update_ is not None:
        cargs.extend([
            "-update",
            str(update_)
        ])
    if no_cent:
        cargs.append("-no_cent")
    if cent:
        cargs.append("-cent")
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    if set_env is not None:
        cargs.extend([
            "-setenv",
            set_env
        ])
    if trace_:
        cargs.append("-trace")
    if trace_extreme:
        cargs.append("-TRACE")
    if no_memory_trace:
        cargs.append("-nomall")
    if yes_memory_trace:
        cargs.append("-yesmall")
    if mini_help:
        cargs.append("-h")
    if help_:
        cargs.append("-help")
    if extreme_help:
        cargs.append("-HELP")
    if view_help:
        cargs.append("-h_view")
    if web_help:
        cargs.append("-h_web")
    if find_help is not None:
        cargs.extend([
            "-h_find",
            find_help
        ])
    if raw_help:
        cargs.append("-h_raw")
    if spx_help:
        cargs.append("-h_spx")
    if aspx_help:
        cargs.append("-h_aspx")
    ret = SurfClustOutputs(
        root=execution.output_file("."),
        cluster_table=execution.output_file(prefix + "_ClstTable_rXX_aXX.1D") if (prefix is not None) else None,
        clustered_dataset=execution.output_file(prefix + "_Clustered_rXX_aXX.dset") if (prefix is not None) else None,
        roi_dataset=execution.output_file(prefix + "_ClstMsk_rXX_aXX.dset") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_CLUST_METADATA",
    "SurfClustOutputs",
    "surf_clust",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_RESAMPLE_METADATA = Metadata(
    id="8e0412fed997d47e43936d5bf5273ec321a5c58a.boutiques",
    name="volume-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeResampleFlirt:
    """
    MUST be used if affine is a flirt affine.
    """
    source_volume: str
    """the source volume used when generating the affine"""
    target_volume: str
    """the target volume used when generating the affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-flirt")
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


@dataclasses.dataclass
class VolumeResampleAffine:
    """
    add an affine transform.
    """
    affine: str
    """the affine file to use"""
    flirt: VolumeResampleFlirt | None = None
    """MUST be used if affine is a flirt affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-affine")
        cargs.append(self.affine)
        if self.flirt is not None:
            cargs.extend(self.flirt.run(execution))
        return cargs


@dataclasses.dataclass
class VolumeResampleFlirt_:
    """
    MUST be used if the affines are flirt affines.
    """
    source_volume: str
    """the source volume used when generating the affine"""
    target_volume: str
    """the target volume used when generating the affine"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-flirt")
        cargs.append(self.source_volume)
        cargs.append(self.target_volume)
        return cargs


@dataclasses.dataclass
class VolumeResampleAffineSeries:
    """
    add an independent affine per-frame.
    """
    affine_series: str
    """text file containing 12 or 16 numbers per line, each being a row-major
    flattened affine"""
    flirt: VolumeResampleFlirt_ | None = None
    """MUST be used if the affines are flirt affines"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-affine-series")
        cargs.append(self.affine_series)
        if self.flirt is not None:
            cargs.extend(self.flirt.run(execution))
        return cargs


@dataclasses.dataclass
class VolumeResampleWarp:
    """
    add a nonlinear warpfield transform.
    """
    warpfield: str
    """the warpfield file"""
    opt_fnirt_source_volume: str | None = None
    """MUST be used if using a fnirt warpfield: the source volume used when
    generating the warpfield"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-warp")
        cargs.append(self.warpfield)
        if self.opt_fnirt_source_volume is not None:
            cargs.extend([
                "-fnirt",
                self.opt_fnirt_source_volume
            ])
        return cargs


class VolumeResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_resample(
    volume_in: InputPathType,
    volume_space: str,
    method: str,
    volume_out: str,
    affine: list[VolumeResampleAffine] | None = None,
    affine_series: list[VolumeResampleAffineSeries] | None = None,
    warp: list[VolumeResampleWarp] | None = None,
    runner: Runner | None = None,
) -> VolumeResampleOutputs:
    """
    Transform and resample a volume file.
    
    Resample a volume file with an arbitrary list of transformations. You may
    specify -affine, -warp, and -affine-series multiple times each, and they
    will be used in the order specified. For instance, for rigid motion
    correction followed by nonlinear atlas registration, specify -affine-series
    first, then -warp. The recommended methods are CUBIC (cubic spline) for most
    data, and ENCLOSING_VOXEL for label data. The parameter <method> must be one
    of:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: volume to resample.
        volume_space: a volume file in the volume space you want for the output.
        method: the resampling method.
        volume_out: the output volume.
        affine: add an affine transform.
        affine_series: add an independent affine per-frame.
        warp: add a nonlinear warpfield transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-resample")
    cargs.append(execution.input_file(volume_in))
    cargs.append(volume_space)
    cargs.append(method)
    cargs.append(volume_out)
    if affine is not None:
        cargs.extend([a for c in [s.run(execution) for s in affine] for a in c])
    if affine_series is not None:
        cargs.extend([a for c in [s.run(execution) for s in affine_series] for a in c])
    if warp is not None:
        cargs.extend([a for c in [s.run(execution) for s in warp] for a in c])
    ret = VolumeResampleOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_RESAMPLE_METADATA",
    "VolumeResampleAffine",
    "VolumeResampleAffineSeries",
    "VolumeResampleFlirt",
    "VolumeResampleFlirt_",
    "VolumeResampleOutputs",
    "VolumeResampleWarp",
    "volume_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_RUN_R_METADATA = Metadata(
    id="c25de8aaab9b4faa0067fa6c9d3361eb1f13f7bf.boutiques",
    name="afni_run_R",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniRunROutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_run_r(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_run_r(
    r_script: InputPathType,
    r_args: list[str],
    runner: Runner | None = None,
) -> AfniRunROutputs:
    """
    Run an R script with the specified arguments.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        r_script: R script to be executed.
        r_args: Arguments to be passed to the R script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniRunROutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_RUN_R_METADATA)
    cargs = []
    cargs.append("afni_run_R")
    cargs.append(execution.input_file(r_script))
    cargs.extend(r_args)
    ret = AfniRunROutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_RUN_R_METADATA",
    "AfniRunROutputs",
    "afni_run_r",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_REDUCE_METADATA = Metadata(
    id="8f69a9fb5fec167f808d9feb0478740e661cda26.boutiques",
    name="metric-reduce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class MetricReduceExcludeOutliers:
    """
    exclude non-numeric values and outliers by standard deviation.
    """
    sigma_below: float
    """number of standard deviations below the mean to include"""
    sigma_above: float
    """number of standard deviations above the mean to include"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-exclude-outliers")
        cargs.append(str(self.sigma_below))
        cargs.append(str(self.sigma_above))
        return cargs


class MetricReduceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_reduce(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_reduce(
    metric_in: InputPathType,
    operation: str,
    metric_out: str,
    exclude_outliers: MetricReduceExcludeOutliers | None = None,
    opt_only_numeric: bool = False,
    runner: Runner | None = None,
) -> MetricReduceOutputs:
    """
    Perform reduction operation across metric columns.
    
    For each surface vertex, takes the data across columns as a vector, and
    performs the specified reduction on it, putting the result into the single
    output column at that vertex. The reduction operators are as follows:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric_in: the metric to reduce.
        operation: the reduction operator to use.
        metric_out: the output metric.
        exclude_outliers: exclude non-numeric values and outliers by standard\
            deviation.
        opt_only_numeric: exclude non-numeric values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricReduceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_REDUCE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-reduce")
    cargs.append(execution.input_file(metric_in))
    cargs.append(operation)
    cargs.append(metric_out)
    if exclude_outliers is not None:
        cargs.extend(exclude_outliers.run(execution))
    if opt_only_numeric:
        cargs.append("-only-numeric")
    ret = MetricReduceOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_REDUCE_METADATA",
    "MetricReduceExcludeOutliers",
    "MetricReduceOutputs",
    "metric_reduce",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TSTAT_METADATA = Metadata(
    id="2c3351f9c202b2f87198789eb63df2ff52ca3826.boutiques",
    name="3dTstat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTstatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tstat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Output image file name."""


def v_3d_tstat(
    in_file: InputPathType,
    mask: InputPathType | None = None,
    num_threads: int | None = None,
    sum_: bool = False,
    abssum: bool = False,
    sos: bool = False,
    l2norm: bool = False,
    mean: bool = False,
    slope: bool = False,
    stdev: bool = False,
    stdev_nod: bool = False,
    cvar: bool = False,
    cvar_nod: bool = False,
    cvarinv: bool = False,
    cvarinv_nod: bool = False,
    tsnr: bool = False,
    mad: bool = False,
    dw: bool = False,
    median: bool = False,
    nzmedian: bool = False,
    nzstdev: bool = False,
    bmv: bool = False,
    mssd: bool = False,
    mssdsqrt: bool = False,
    masdx: bool = False,
    min_: bool = False,
    max_: bool = False,
    absmax: bool = False,
    signed_absmax: bool = False,
    percentile: bool = False,
    argmin: bool = False,
    argmin1: bool = False,
    argmax: bool = False,
    argmax1: bool = False,
    argabsmax: bool = False,
    argabsmax1: bool = False,
    duration: bool = False,
    onset: bool = False,
    offset: bool = False,
    centroid: bool = False,
    centduration: bool = False,
    nzmean: bool = False,
    zcount: bool = False,
    nzcount: bool = False,
    autocorr: bool = False,
    autoreg: bool = False,
    accumulate: bool = False,
    centromean: bool = False,
    skewness: bool = False,
    kurtosis: bool = False,
    firstvalue: bool = False,
    tdiff: bool = False,
    prefix: str | None = None,
    datum: str | None = None,
    nscale: bool = False,
    basepercent: float | None = None,
    mask_mset: InputPathType | None = None,
    mrange: str | None = None,
    cmask: str | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    runner: Runner | None = None,
) -> V3dTstatOutputs:
    """
    Compute voxel-wise statistics using AFNI 3dTstat command.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3dtstat.
        mask: Mask file.
        num_threads: Set number of threads.
        sum_: Compute sum of input voxels.
        abssum: Compute absolute sum of input voxels.
        sos: Compute sum of squares.
        l2norm: Compute L2 norm (sqrt(sum squares)).
        mean: Compute mean of input voxels.
        slope: Compute the slope of input voxels vs. time.
        stdev: Compute standard deviation of input voxels.
        stdev_nod: Compute standard deviation of input voxels without\
            detrending.
        cvar: Compute coefficient of variation of input voxels.
        cvar_nod: Compute coefficient of variation of input voxels without\
            detrending.
        cvarinv: Compute inverse coefficient of variation of input voxels.
        cvarinv_nod: Compute inverse coefficient of variation of input voxels\
            without detrending.
        tsnr: Compute temporal signal to noise ratio.
        mad: Compute median absolute deviation of input voxels.
        dw: Compute Durbin-Watson Statistic of input voxels.
        median: Compute median of input voxels.
        nzmedian: Compute median of non-zero input voxels.
        nzstdev: Compute standard deviation of non-zero input voxels.
        bmv: Compute biweight midvariance of input voxels.
        mssd: Compute mean of successive squared differences of input voxels.
        mssdsqrt: Compute square root of mean of successive squared differences\
            of input voxels.
        masdx: Compute median of absolute values of first time differences of\
            input voxels.
        min_: Compute minimum of input voxels.
        max_: Compute maximum of input voxels.
        absmax: Compute absolute maximum of input voxels.
        signed_absmax: Compute signed absolute maximum of input voxels.
        percentile: Compute the P-th percentile point of the data in each voxel\
            time series.
        argmin: Compute index of minimum of input voxels.
        argmin1: Compute index + 1 of minimum of input voxels.
        argmax: Compute index of maximum of input voxels.
        argmax1: Compute index + 1 of maximum of input voxels.
        argabsmax: Compute index of absolute maximum of input voxels.
        argabsmax1: Compute index + 1 of absolute maximum of input voxels.
        duration: Compute number of points around max above a threshold.
        onset: Compute beginning of duration around max where value exceeds\
            basepercent.
        offset: Compute end of duration around max where value exceeds\
            basepercent.
        centroid: Compute centroid of data time curves.
        centduration: Compute duration using centroid's index as center.
        nzmean: Compute mean of non-zero voxels.
        zcount: Count number of zero values at each voxel.
        nzcount: Count number of non-zero values at each voxel.
        autocorr: Compute autocorrelation function and return first n\
            coefficients.
        autoreg: Compute autoregression coefficients and return first n\
            coefficients.
        accumulate: Accumulate time series values (partial sums).
        centromean: Compute mean of middle 50% of voxel values.
        skewness: Measure of asymmetry in distribution.
        kurtosis: Measure of the 'tailedness' of the probability distribution.
        firstvalue: First value in dataset.
        tdiff: Take the first difference of each time series before further\
            processing.
        prefix: Use string 'p' for the prefix of the output dataset [DEFAULT =\
            'stat'].
        datum: Use data type 'd' for the type of storage of the output, where\
            'd' is one of 'byte', 'short', or 'float' [DEFAULT=float].
        nscale: Do not scale output values when datum is byte or short. Scaling\
            is done by default.
        basepercent: Percentage of maximum for duration calculation.
        mask_mset: Use the dataset 'mset' as a mask. Only voxels with nonzero\
            values in 'mset' will be printed from 'dataset'.
        mrange: Further restrict the voxels from 'mset' so that only those mask\
            values between 'a' and 'b' (inclusive) will be used.
        cmask: Execute the options enclosed in single quotes as a 3dcalc-like\
            program, and produce a mask from the resulting 3D brick.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTstatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TSTAT_METADATA)
    cargs = []
    cargs.append("3dTstat")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if num_threads is not None:
        cargs.append(str(num_threads))
    if sum_:
        cargs.append("-sum")
    if abssum:
        cargs.append("-abssum")
    if sos:
        cargs.append("-sos")
    if l2norm:
        cargs.append("-l2norm")
    if mean:
        cargs.append("-mean")
    if slope:
        cargs.append("-slope")
    if stdev:
        cargs.append("-stdev")
    if stdev_nod:
        cargs.append("-stdevNOD")
    if cvar:
        cargs.append("-cvar")
    if cvar_nod:
        cargs.append("-cvarNOD")
    if cvarinv:
        cargs.append("-cvarinv")
    if cvarinv_nod:
        cargs.append("-cvarinvNOD")
    if tsnr:
        cargs.append("-tsnr")
    if mad:
        cargs.append("-MAD")
    if dw:
        cargs.append("-DW")
    if median:
        cargs.append("-median")
    if nzmedian:
        cargs.append("-nzmedian")
    if nzstdev:
        cargs.append("-nzstdev")
    if bmv:
        cargs.append("-bmv")
    if mssd:
        cargs.append("-MSSD")
    if mssdsqrt:
        cargs.append("-MSSDsqrt")
    if masdx:
        cargs.append("-MASDx")
    if min_:
        cargs.append("-min")
    if max_:
        cargs.append("-max")
    if absmax:
        cargs.append("-absmax")
    if signed_absmax:
        cargs.append("-signed_absmax")
    if percentile:
        cargs.append("-percentile")
    if argmin:
        cargs.append("-argmin")
    if argmin1:
        cargs.append("-argmin1")
    if argmax:
        cargs.append("-argmax")
    if argmax1:
        cargs.append("-argmax1")
    if argabsmax:
        cargs.append("-argabsmax")
    if argabsmax1:
        cargs.append("-argabsmax1")
    if duration:
        cargs.append("-duration")
    if onset:
        cargs.append("-onset")
    if offset:
        cargs.append("-offset")
    if centroid:
        cargs.append("-centroid")
    if centduration:
        cargs.append("-centduration")
    if nzmean:
        cargs.append("-nzmean")
    if zcount:
        cargs.append("-zcount")
    if nzcount:
        cargs.append("-nzcount")
    if autocorr:
        cargs.append("-autocorr")
    if autoreg:
        cargs.append("-autoreg")
    if accumulate:
        cargs.append("-accumulate")
    if centromean:
        cargs.append("-centromean")
    if skewness:
        cargs.append("-skewness")
    if kurtosis:
        cargs.append("-kurtosis")
    if firstvalue:
        cargs.append("-firstvalue")
    if tdiff:
        cargs.append("-tdiff")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    if nscale:
        cargs.append("-nscale")
    if basepercent is not None:
        cargs.extend([
            "-basepercent",
            str(basepercent)
        ])
    if mask_mset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_mset)
        ])
    if mrange is not None:
        cargs.extend([
            "-mrange",
            mrange
        ])
    if cmask is not None:
        cargs.extend([
            "-cmask",
            cmask
        ])
    if outputtype is not None:
        cargs.append(outputtype)
    cargs.append(execution.input_file(in_file))
    ret = V3dTstatOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(prefix) if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTstatOutputs",
    "V_3D_TSTAT_METADATA",
    "v_3d_tstat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_AC_SH_METADATA = Metadata(
    id="a5e9ef0f18ba9932988056847d608cbe806d5bed.boutiques",
    name="dmri_ac.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriAcShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_ac_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_ac_sh(
    additional_args: str | None = None,
    runner: Runner | None = None,
) -> DmriAcShOutputs:
    """
    A script related to diffusion MRI processing in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        additional_args: Additional arguments for dmri_ac.sh script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriAcShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_AC_SH_METADATA)
    cargs = []
    cargs.append("dmri_ac.sh")
    if additional_args is not None:
        cargs.append(additional_args)
    ret = DmriAcShOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_AC_SH_METADATA",
    "DmriAcShOutputs",
    "dmri_ac_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_RESAMPLE_METADATA = Metadata(
    id="58c882ffaf4fe37d2d5aa57751a90cb1600aab80.boutiques",
    name="mris_resample",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resampled_surface_output: OutputPathType
    """Resampled surface output"""
    resampled_annotation_output: OutputPathType | None
    """Output annotation for the resampled atlas"""


def mris_resample(
    atlas_reg: InputPathType,
    subject_reg: InputPathType,
    subject_surf: InputPathType,
    output: InputPathType,
    annot_in: InputPathType | None = None,
    annot_out: InputPathType | None = None,
    runner: Runner | None = None,
) -> MrisResampleOutputs:
    """
    Resample cortical surfaces in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        atlas_reg: Atlas spherical registration file.
        subject_reg: Subject spherical registration file.
        subject_surf: Subject actual surface.
        output: Output resampled surface.
        annot_in: Input annotation (for the subject). If present, output\
            annotation must be present as well.
        annot_out: Output annotation (for the resampled atlas). If present,\
            input annotation must be present as well.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_RESAMPLE_METADATA)
    cargs = []
    cargs.append("mris_resample")
    cargs.extend([
        "-atlas_reg",
        execution.input_file(atlas_reg)
    ])
    cargs.extend([
        "-subject_reg",
        execution.input_file(subject_reg)
    ])
    cargs.extend([
        "-subject_surf",
        execution.input_file(subject_surf)
    ])
    cargs.extend([
        "-out",
        execution.input_file(output)
    ])
    if annot_in is not None:
        cargs.extend([
            "--annot_in",
            execution.input_file(annot_in)
        ])
    if annot_out is not None:
        cargs.extend([
            "--annot_out",
            execution.input_file(annot_out)
        ])
    ret = MrisResampleOutputs(
        root=execution.output_file("."),
        resampled_surface_output=execution.output_file(pathlib.Path(output).name),
        resampled_annotation_output=execution.output_file(pathlib.Path(annot_out).name) if (annot_out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_RESAMPLE_METADATA",
    "MrisResampleOutputs",
    "mris_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TKMEDIT_METADATA = Metadata(
    id="215f4c63f4d1d614a5f6ddc04a121949f2f19d48.boutiques",
    name="tkmedit",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TkmeditOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tkmedit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tkmedit(
    input_volume: InputPathType,
    options: str | None = None,
    runner: Runner | None = None,
) -> TkmeditOutputs:
    """
    tkmedit is a multi-functional imaging tool for viewing and editing surface
    models and volumes in FreeSurfer. It provides a GUI representation of volumetric
    data and facilitates modifications in the data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file (e.g., nu.mgz or brain.mgz).
        options: Options for running tkmedit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TkmeditOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TKMEDIT_METADATA)
    cargs = []
    cargs.append("tkmedit")
    cargs.append(execution.input_file(input_volume))
    if options is not None:
        cargs.append(options)
    ret = TkmeditOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TKMEDIT_METADATA",
    "TkmeditOutputs",
    "tkmedit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT3_METADATA = Metadata(
    id="a274d70311c1a539bade6099eed3c3f3614e2009.boutiques",
    name="inflate_subject3",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubject3Outputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject3(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def inflate_subject3(
    subjects_dir: str,
    script_name: str,
    runner: Runner | None = None,
) -> InflateSubject3Outputs:
    """
    A tool related to subject inflation in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects_dir: The directory where FreeSurfer subjects are stored.
        script_name: The name of the script to be executed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubject3Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT3_METADATA)
    cargs = []
    cargs.append("inflate_subject3")
    cargs.append(subjects_dir)
    cargs.append(script_name)
    ret = InflateSubject3Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT3_METADATA",
    "InflateSubject3Outputs",
    "inflate_subject3",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_ANNOTATION2LABEL_METADATA = Metadata(
    id="90b6d8bcd55a8d08f2bccdf11454197b855e2864.boutiques",
    name="mri_annotation2label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriAnnotation2labelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_annotation2label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_annotation2label(
    subject: str,
    hemi: str,
    lobes: InputPathType | None = None,
    lobes_strict: InputPathType | None = None,
    lobes_strict_phcg: InputPathType | None = None,
    label: float | None = None,
    labelbase: str | None = None,
    outdir: str | None = None,
    seg: InputPathType | None = None,
    segbase: float | None = None,
    ctab: InputPathType | None = None,
    border: InputPathType | None = None,
    border_annot: str | None = None,
    annotation: str | None = None,
    subjects_dir: str | None = None,
    surface: str | None = None,
    stat_: InputPathType | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriAnnotation2labelOutputs:
    """
    Convert an annotation into multiple label files or into a segmentation volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Source subject.
        hemi: Hemisphere (lh or rh) with surface.
        lobes: Create an annotation based on cortical lobes, saved to\
            <LobesFile>.
        lobes_strict: Use a stricter lobe definition with precentral added to\
            'frontal' and postcentral with 'parietal', saved to <LobesFile>.
        lobes_strict_phcg: Use a stricter lobe definition with an additional\
            lobe 'parahippocampalgyrus', saved to <LobesFile>.
        label: Extract only single label.
        labelbase: Output will be base-XXX.label.
        outdir: Output will be in dir/hemi.name.label.
        seg: Output will be a segmentation volume.
        segbase: Add base to the annotation number to get segmentation value.
        ctab: Color table, like FreeSurferColorLUT.txt.
        border: Output will be a binary overlay of the parc borders.
        border_annot: Default goes in subject/label.
        annotation: As found in SUBJDIR/labels <aparc>.
        subjects_dir: Specify SUBJECTS_DIR on the command line.
        surface: Name of surface <white>. Only affect xyz in label.
        stat_: Surface overlay file (curv or volume format).
        help_: Display help.
        version: Display version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriAnnotation2labelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_ANNOTATION2LABEL_METADATA)
    cargs = []
    cargs.append("mri_annotation2label")
    cargs.extend([
        "--subject",
        subject
    ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    if lobes is not None:
        cargs.extend([
            "--lobes",
            execution.input_file(lobes)
        ])
    if lobes_strict is not None:
        cargs.extend([
            "--lobesStrict",
            execution.input_file(lobes_strict)
        ])
    if lobes_strict_phcg is not None:
        cargs.extend([
            "--lobesStrictPHCG",
            execution.input_file(lobes_strict_phcg)
        ])
    if label is not None:
        cargs.extend([
            "--label",
            str(label)
        ])
    if labelbase is not None:
        cargs.extend([
            "--labelbase",
            labelbase
        ])
    if outdir is not None:
        cargs.extend([
            "--outdir",
            outdir
        ])
    if seg is not None:
        cargs.extend([
            "--seg",
            execution.input_file(seg)
        ])
    if segbase is not None:
        cargs.extend([
            "--segbase",
            str(segbase)
        ])
    if ctab is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab)
        ])
    if border is not None:
        cargs.extend([
            "--border",
            execution.input_file(border)
        ])
    if border_annot is not None:
        cargs.extend([
            "--border-annot",
            border_annot
        ])
    if annotation is not None:
        cargs.extend([
            "--annotation",
            annotation
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if surface is not None:
        cargs.extend([
            "--surface",
            surface
        ])
    if stat_ is not None:
        cargs.extend([
            "--stat",
            execution.input_file(stat_)
        ])
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MriAnnotation2labelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_ANNOTATION2LABEL_METADATA",
    "MriAnnotation2labelOutputs",
    "mri_annotation2label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GET_LABEL_THICKNESS_METADATA = Metadata(
    id="dee540c5d6addffa9eea35a7fd1572afd491a587.boutiques",
    name="get_label_thickness",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GetLabelThicknessOutputs(typing.NamedTuple):
    """
    Output object returned when calling `get_label_thickness(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def get_label_thickness(
    infile: InputPathType,
    runner: Runner | None = None,
) -> GetLabelThicknessOutputs:
    """
    Tool to calculate label thickness.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GetLabelThicknessOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GET_LABEL_THICKNESS_METADATA)
    cargs = []
    cargs.append("get_label_thickness")
    cargs.append(execution.input_file(infile))
    cargs.append("[OPTIONS]")
    ret = GetLabelThicknessOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GET_LABEL_THICKNESS_METADATA",
    "GetLabelThicknessOutputs",
    "get_label_thickness",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_SIMPLIFY_COST_METADATA = Metadata(
    id="0291c293f6b2eaf6626f15fdc0c7c7079ef500e7.boutiques",
    name="adjunct_simplify_cost",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctSimplifyCostOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_simplify_cost(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def adjunct_simplify_cost(
    cost_function: str,
    runner: Runner | None = None,
) -> AdjunctSimplifyCostOutputs:
    """
    Simplifies a cost function name by removing the '+' and anything following it.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        cost_function: The cost function name to be simplified.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctSimplifyCostOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_SIMPLIFY_COST_METADATA)
    cargs = []
    cargs.append("adjunct_simplify_cost.py")
    cargs.append(cost_function)
    ret = AdjunctSimplifyCostOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_SIMPLIFY_COST_METADATA",
    "AdjunctSimplifyCostOutputs",
    "adjunct_simplify_cost",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_AVERAGE_SURFACE_METADATA = Metadata(
    id="f27d1881cb0ec462784332cf8519b93ee957748e.boutiques",
    name="make_average_surface",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeAverageSurfaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_average_surface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def make_average_surface(
    subjects: list[str],
    fsgd_file: InputPathType | None = None,
    average_subject_name: str | None = "average",
    subjects_dir: str | None = None,
    sd_out_dir: str | None = None,
    transform_file: str | None = None,
    icosahedron_number: float | None = 7,
    surf_reg: str | None = None,
    left_hemi: bool = False,
    right_hemi: bool = False,
    force: bool = False,
    annot_template: bool = False,
    template_only: bool = False,
    no_template_only: bool = False,
    no_annot: bool = False,
    no_cortex_label: bool = False,
    annot_list: list[str] | None = None,
    meas_list: list[str] | None = None,
    no_surf2surf: bool = False,
    no_symlink: bool = False,
    version: bool = False,
    echo: bool = False,
    runner: Runner | None = None,
) -> MakeAverageSurfaceOutputs:
    """
    Creates average surfaces and curvatures from a set of subjects.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjects: List of subject names.
        fsgd_file: File from which to get the subject list.
        average_subject_name: Average subject name.
        subjects_dir: Directory for SUBJECTS_DIR (if different from the\
            environment variable).
        sd_out_dir: Directory to put output data.
        transform_file: Filename of the transform file.
        icosahedron_number: Specify icosahedron number.
        surf_reg: Alternative registration surface name.
        left_hemi: Only process the left hemisphere.
        right_hemi: Only process the right hemisphere.
        force: Overwrite existing average subject data.
        annot_template: Use annotation when making tif.
        template_only: Useful when creating iterative atlases.
        no_template_only: Turns off --template-only.
        no_annot: Do not create average annotations.
        no_cortex_label: Do not create ?h.cortex.label.
        annot_list: List of annotations to use.
        meas_list: List of measurements to use.
        no_surf2surf: Use old parametric surface method.
        no_symlink: Do not use symbolic links, just copy files.
        version: Script version information.
        echo: Enable command echo for debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeAverageSurfaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_AVERAGE_SURFACE_METADATA)
    cargs = []
    cargs.append("make_average_surface")
    cargs.extend(subjects)
    if fsgd_file is not None:
        cargs.extend([
            "--fsgd",
            execution.input_file(fsgd_file)
        ])
    if average_subject_name is not None:
        cargs.extend([
            "--out",
            average_subject_name
        ])
    if subjects_dir is not None:
        cargs.extend([
            "--sdir",
            subjects_dir
        ])
    if sd_out_dir is not None:
        cargs.extend([
            "--sd-out",
            sd_out_dir
        ])
    if transform_file is not None:
        cargs.extend([
            "--xform",
            transform_file
        ])
    if icosahedron_number is not None:
        cargs.extend([
            "--ico",
            str(icosahedron_number)
        ])
    if surf_reg is not None:
        cargs.extend([
            "--surf-reg",
            surf_reg
        ])
    if left_hemi:
        cargs.append("--lh")
    if right_hemi:
        cargs.append("--rh")
    if force:
        cargs.append("--force")
    if annot_template:
        cargs.append("--annot-template")
    if template_only:
        cargs.append("--template-only")
    if no_template_only:
        cargs.append("--no-template-only")
    if no_annot:
        cargs.append("--no-annot")
    if no_cortex_label:
        cargs.append("--no-cortex-label")
    if annot_list is not None:
        cargs.extend([
            "--annot",
            *annot_list
        ])
    if meas_list is not None:
        cargs.extend([
            "--meas",
            *meas_list
        ])
    if no_surf2surf:
        cargs.append("--no-surf2surf")
    if no_symlink:
        cargs.append("--no-symlink")
    if version:
        cargs.append("--version")
    if echo:
        cargs.append("--echo")
    ret = MakeAverageSurfaceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_AVERAGE_SURFACE_METADATA",
    "MakeAverageSurfaceOutputs",
    "make_average_surface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUICKSPEC_SL_METADATA = Metadata(
    id="6ad0ef7a3cf68472db5f2c42ec5677d562d0ca24.boutiques",
    name="quickspecSL",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QuickspecSlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quickspec_sl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_spec_file: OutputPathType | None
    """Output spec file"""


def quickspec_sl(
    surf_a: InputPathType,
    surf_b: InputPathType,
    surf_intermed_pref: str | None = None,
    infl_surf_a: InputPathType | None = None,
    infl_surf_b: InputPathType | None = None,
    infl_surf_intermed_pref: str | None = None,
    both_lr_flag: bool = False,
    out_spec: str | None = None,
    runner: Runner | None = None,
) -> QuickspecSlOutputs:
    """
    This program makes a *.spec file after a set of intermediate surfaces have been
    generated with SurfLayers. It can also make a *.spec file that relates inflated
    surfaces to anatomically-correct surfaces.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        surf_a: Inner (anatomically-correct) boundary surface dataset (e.g.\
            smoothwm.gii).
        surf_b: Outer (anatomically-correct) boundary surface dataset (e.g.\
            pial.gii).
        surf_intermed_pref: Prefix for (anatomically-correct) intermediate\
            surfaces, typically output by SurfLayers (default: isurf).
        infl_surf_a: Inner (inflated) boundary surface dataset (e.g.\
            infl.smoothwm.gii).
        infl_surf_b: Outer (inflated) boundary surface dataset (e.g.\
            infl.pial.gii).
        infl_surf_intermed_pref: Prefix for (inflated) intermediate surfaces,\
            typically output by SurfLayers (default: infl.isurf).
        both_lr_flag: Specify an output spec for both hemispheres if surfaces\
            for both exist.
        out_spec: Name for output *.spec file (default: newspec.spec).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuickspecSlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUICKSPEC_SL_METADATA)
    cargs = []
    cargs.append("quickspecSL")
    cargs.extend([
        "-surf_A",
        execution.input_file(surf_a)
    ])
    cargs.extend([
        "-surf_B",
        execution.input_file(surf_b)
    ])
    if surf_intermed_pref is not None:
        cargs.extend([
            "-surf_intermed_pref",
            surf_intermed_pref
        ])
    if infl_surf_a is not None:
        cargs.extend([
            "-infl_surf_A",
            execution.input_file(infl_surf_a)
        ])
    if infl_surf_b is not None:
        cargs.extend([
            "-infl_surf_B",
            execution.input_file(infl_surf_b)
        ])
    if infl_surf_intermed_pref is not None:
        cargs.extend([
            "-infl_surf_intermed_pref",
            infl_surf_intermed_pref
        ])
    if both_lr_flag:
        cargs.append("-both_lr")
    if out_spec is not None:
        cargs.extend([
            "-out_spec",
            out_spec
        ])
    ret = QuickspecSlOutputs(
        root=execution.output_file("."),
        output_spec_file=execution.output_file(out_spec) if (out_spec is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUICKSPEC_SL_METADATA",
    "QuickspecSlOutputs",
    "quickspec_sl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_LABEL_HISTO_METADATA = Metadata(
    id="279e3275146be4635a5b307d29d8143bca5b3d20.boutiques",
    name="mri_label_histo",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriLabelHistoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_label_histo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    histogram_output: OutputPathType
    """Histogram of voxel values for the specified label."""


def mri_label_histo(
    t1_volume: InputPathType,
    labeled_volume: InputPathType,
    label: float,
    output: str,
    runner: Runner | None = None,
) -> MriLabelHistoOutputs:
    """
    Tool for creating a histogram of voxel values within a specified label.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1_volume: Input T1-weighted anatomical volume.
        labeled_volume: Input volume with labeled regions.
        label: Label of the region of interest.
        output: Output file for histogram.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriLabelHistoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_LABEL_HISTO_METADATA)
    cargs = []
    cargs.append("mri_label_histo")
    cargs.append(execution.input_file(t1_volume))
    cargs.append(execution.input_file(labeled_volume))
    cargs.append(str(label))
    cargs.append(output)
    ret = MriLabelHistoOutputs(
        root=execution.output_file("."),
        histogram_output=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_LABEL_HISTO_METADATA",
    "MriLabelHistoOutputs",
    "mri_label_histo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GEN_SS_REVIEW_TABLE_PY_METADATA = Metadata(
    id="14139376af49e78f5d6fa5b8178a8e41bcf15797.boutiques",
    name="gen_ss_review_table.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GenSsReviewTablePyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gen_ss_review_table_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_table: OutputPathType | None
    """Final table output file"""
    output_outliers: OutputPathType | None
    """Outliers table output file"""


def gen_ss_review_table_py(
    infiles: list[InputPathType],
    write_table: InputPathType | None = None,
    write_outliers: InputPathType | None = None,
    overwrite: bool = False,
    empty_is_outlier: bool = False,
    outlier_sep: str | None = None,
    separator: str | None = None,
    showlabs: bool = False,
    show_infiles: bool = False,
    show_keepers: bool = False,
    report_outliers: list[str] | None = None,
    report_outliers_fill_style: str | None = None,
    show_missing: bool = False,
    verbosity: int | None = None,
    runner: Runner | None = None,
) -> GenSsReviewTablePyOutputs:
    """
    Generate a table from ss_review_basic output files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infiles: Input ss_review_basic output text files to process.
        write_table: Write final table to the given file.
        write_outliers: Write outlier table to the given file.
        overwrite: Overwrite the output -write_table, if it exists.
        empty_is_outlier: Treat empty tests as outliers.
        outlier_sep: Use SEP for the outlier table separator.
        separator: Use SEP for the label/vals separator (default = ':').
        showlabs: Display counts of all labels found, with parents.
        show_infiles: Include input files in reviewtable result.
        show_keepers: Show a table of subjects kept rather than dropped.
        report_outliers: Report outliers where the comparison holds.
        report_outliers_fill_style: How to fill non-outliers in the table.
        show_missing: Display all missing keys.
        verbosity: Verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GenSsReviewTablePyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GEN_SS_REVIEW_TABLE_PY_METADATA)
    cargs = []
    cargs.append("gen_ss_review_table.py")
    cargs.extend([execution.input_file(f) for f in infiles])
    if write_table is not None:
        cargs.extend([
            "-write_table",
            execution.input_file(write_table)
        ])
    if write_outliers is not None:
        cargs.extend([
            "-write_outliers",
            execution.input_file(write_outliers)
        ])
    if overwrite:
        cargs.append("-overwrite")
    if empty_is_outlier:
        cargs.append("-empty_is_outlier")
    if outlier_sep is not None:
        cargs.extend([
            "-outlier_sep",
            outlier_sep
        ])
    if separator is not None:
        cargs.extend([
            "-separator",
            separator
        ])
    if showlabs:
        cargs.append("-showlabs")
    if show_infiles:
        cargs.append("-show_infiles")
    if show_keepers:
        cargs.append("-show_keepers")
    if report_outliers is not None:
        cargs.extend([
            "-report_outliers",
            *report_outliers
        ])
    if report_outliers_fill_style is not None:
        cargs.extend([
            "-report_outliers_fill_style",
            report_outliers_fill_style
        ])
    if show_missing:
        cargs.append("-show_missing")
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    ret = GenSsReviewTablePyOutputs(
        root=execution.output_file("."),
        output_table=execution.output_file(pathlib.Path(write_table).name) if (write_table is not None) else None,
        output_outliers=execution.output_file(pathlib.Path(write_outliers).name) if (write_outliers is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GEN_SS_REVIEW_TABLE_PY_METADATA",
    "GenSsReviewTablePyOutputs",
    "gen_ss_review_table_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SLICEDELAY_METADATA = Metadata(
    id="e0e78eeb6a32014e4f62ce730e136633e9ef9494.boutiques",
    name="slicedelay",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SlicedelayOutputs(typing.NamedTuple):
    """
    Output object returned when calling `slicedelay(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    slicedelayfile: OutputPathType
    """The generated slice delay file"""


def slicedelay(
    slicedelayfile: str,
    nslices: float,
    order: typing.Literal["up", "down", "odd", "even", "siemens"],
    ngroups: float,
    runner: Runner | None = None,
) -> SlicedelayOutputs:
    """
    Creates an FSL custom slice delay file for use with slicetimer for slice-time
    correction of fMRI.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        slicedelayfile: Output file for the custom slice delay.
        nslices: Total number of slices in the volume.
        order: Order of slices (up, down, odd, even, siemens).
        ngroups: Number of slice groups for SMS.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SlicedelayOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SLICEDELAY_METADATA)
    cargs = []
    cargs.append("slicedelay")
    cargs.extend([
        "--o",
        slicedelayfile
    ])
    cargs.extend([
        "--nslices",
        str(nslices)
    ])
    cargs.extend([
        "--order",
        order
    ])
    cargs.extend([
        "--ngroups",
        str(ngroups)
    ])
    ret = SlicedelayOutputs(
        root=execution.output_file("."),
        slicedelayfile=execution.output_file(slicedelayfile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SLICEDELAY_METADATA",
    "SlicedelayOutputs",
    "slicedelay",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_VERSION_METADATA = Metadata(
    id="00b4038dc7dd30e795e94e467e6a777717d8d741.boutiques",
    name="@get.afni.version",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniVersionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_version(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    src_dir: OutputPathType
    """Directory containing the downloaded AFNI source code for the specified
    version."""


def v__get_afni_version(
    version: str,
    runner: Runner | None = None,
) -> VGetAfniVersionOutputs:
    """
    Downloads the source code for a specified AFNI version.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        version: AFNI version number to get (e.g., 16.0.01).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniVersionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_VERSION_METADATA)
    cargs = []
    cargs.append("@get.afni.version")
    cargs.append(version)
    ret = VGetAfniVersionOutputs(
        root=execution.output_file("."),
        src_dir=execution.output_file("AFNI_" + version + "/AFNI/src"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniVersionOutputs",
    "V__GET_AFNI_VERSION_METADATA",
    "v__get_afni_version",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STD2IMGCOORD_METADATA = Metadata(
    id="05322cde0f0612798367ff4b15825c44466bc700.boutiques",
    name="std2imgcoord",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Std2imgcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `std2imgcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def std2imgcoord(
    filename_coordinates: InputPathType,
    input_image: InputPathType,
    standard_image: InputPathType | None = None,
    affine_transform: InputPathType | None = None,
    warp_field: InputPathType | None = None,
    prewarp_affine_transform: InputPathType | None = None,
    output_mm: bool = False,
    output_vox: bool = False,
    verbose: bool = False,
    more_verbose: bool = False,
    runner: Runner | None = None,
) -> Std2imgcoordOutputs:
    """
    Convert standard space coordinates to image space coordinates.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        filename_coordinates: Path to the filename containing coordinates or\
            '-' to read from standard input.
        input_image: Filename of input image.
        standard_image: Filename of standard image.
        affine_transform: Filename of affine transform (e.g.\
            example_func2standard.mat).
        warp_field: Filename of warpfield (e.g. highres2standard_warp.nii.gz).
        prewarp_affine_transform: Filename of pre-warp affine transform (e.g.\
            example_func2highres.mat). Defaults to identity matrix.
        output_mm: Outputs coordinates in mm (default).
        output_vox: Outputs coordinates in voxels.
        verbose: Verbose output.
        more_verbose: More verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Std2imgcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STD2IMGCOORD_METADATA)
    cargs = []
    cargs.append("std2imgcoord")
    cargs.append(execution.input_file(filename_coordinates))
    if standard_image is not None:
        cargs.extend([
            "-std",
            execution.input_file(standard_image)
        ])
    cargs.extend([
        "-img",
        execution.input_file(input_image)
    ])
    if affine_transform is not None:
        cargs.extend([
            "-xfm",
            execution.input_file(affine_transform)
        ])
    if warp_field is not None:
        cargs.extend([
            "-warp",
            execution.input_file(warp_field)
        ])
    if prewarp_affine_transform is not None:
        cargs.extend([
            "-premat",
            execution.input_file(prewarp_affine_transform)
        ])
    if output_mm:
        cargs.append("-mm")
    if output_vox:
        cargs.append("-vox")
    if verbose:
        cargs.append("-v")
    if more_verbose:
        cargs.append("-verbose")
    ret = Std2imgcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STD2IMGCOORD_METADATA",
    "Std2imgcoordOutputs",
    "std2imgcoord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_BPORT_METADATA = Metadata(
    id="4be892d519b77ae339eb9adf3a74b7d897d73650.boutiques",
    name="1dBport",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dBportOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_bport(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """Standard output file written by the tool"""


def v_1d_bport(
    band: list[float],
    invert: bool = False,
    noconst: bool = False,
    quad: bool = False,
    input_dataset: InputPathType | None = None,
    input_1d_file: InputPathType | None = None,
    nodata: list[float] | None = None,
    tr: float | None = None,
    concat: InputPathType | None = None,
    runner: Runner | None = None,
) -> V1dBportOutputs:
    """
    Creates a set of columns of sines and cosines for bandpassing via regression.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        band: Specify lowest and highest frequencies in the passband.
        invert: Invert the selection after computing which frequency indexes\
            correspond to the input band(s).
        noconst: Same as -nozero. Do NOT generate the 0 frequency (constant)\
            component when fbot = 0.
        quad: Add regressors for linear and quadratic trends.
        input_dataset: Specify the dataset input.
        input_1d_file: Specify the 1D input file.
        nodata: Specify the number of time points and optionally TR value for\
            the simulation.
        tr: Set the time step duration.
        concat: Specify the list of start indexes for concatenated runs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dBportOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_BPORT_METADATA)
    cargs = []
    cargs.append("1dBport")
    cargs.extend([
        "-band",
        *map(str, band)
    ])
    if invert:
        cargs.append("-invert")
    if noconst:
        cargs.append("-noconst")
    if quad:
        cargs.append("-quad")
    if input_dataset is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_dataset)
        ])
    if input_1d_file is not None:
        cargs.extend([
            "-input1D",
            execution.input_file(input_1d_file)
        ])
    if nodata is not None:
        cargs.extend([
            "-nodata",
            *map(str, nodata)
        ])
    if tr is not None:
        cargs.extend([
            "-TR",
            str(tr)
        ])
    if concat is not None:
        cargs.extend([
            "-concat",
            execution.input_file(concat)
        ])
    ret = V1dBportOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dBportOutputs",
    "V_1D_BPORT_METADATA",
    "v_1d_bport",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MOTION_CORRECT2_METADATA = Metadata(
    id="a581289aa8203d417a44a5b02cbe1c9a50b8b234.boutiques",
    name="mri_motion_correct2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMotionCorrect2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_motion_correct2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The aligned and averaged output file or directory"""


def mri_motion_correct2(
    output_spec: str,
    input_files: list[InputPathType],
    target: InputPathType | None = None,
    wild: bool = False,
    tmp_dir: str | None = None,
    nocleanup: bool = False,
    umask: str | None = None,
    cm: bool = False,
    version: bool = False,
    debug: bool = False,
    runner: Runner | None = None,
) -> MriMotionCorrect2Outputs:
    """
    Aligns and averages two or more volumes using minctracc for alignment and
    mincresample and mincaverage for resampling.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_spec: Output file or directory (for COR format).
        input_files: Input volume files, specified multiple times for multiple\
            files.
        target: Use the specified target instead of the first input file.
        wild: Assume unmatched arguments are input files.
        tmp_dir: Directory for temporary files.
        nocleanup: Do not delete temporary files.
        umask: Set UNIX file permission mask.
        cm: Make COR volumes conform to minimum voxel size.
        version: Print version information and exit.
        debug: Print detailed debug information to screen.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMotionCorrect2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MOTION_CORRECT2_METADATA)
    cargs = []
    cargs.append("mri_motion_correct2")
    cargs.extend([
        "-o",
        output_spec
    ])
    cargs.extend([
        "-i",
        *[execution.input_file(f) for f in input_files]
    ])
    if target is not None:
        cargs.extend([
            "-t",
            execution.input_file(target)
        ])
    if wild:
        cargs.append("-wild")
    if tmp_dir is not None:
        cargs.extend([
            "-tmpdir",
            tmp_dir
        ])
    if nocleanup:
        cargs.append("-nocleanup")
    if umask is not None:
        cargs.extend([
            "-umask",
            umask
        ])
    if cm:
        cargs.append("-cm")
    if version:
        cargs.append("-version")
    if debug:
        cargs.append("-debug")
    ret = MriMotionCorrect2Outputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_spec),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MOTION_CORRECT2_METADATA",
    "MriMotionCorrect2Outputs",
    "mri_motion_correct2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_CORTICAL_THICKNESS_SH_METADATA = Metadata(
    id="927ff3d34dcb64b2fcbc355449b1223268e7ab32.boutiques",
    name="antsCorticalThickness.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsCorticalThicknessShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_cortical_thickness_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cortical_thickness: OutputPathType
    """The output cortical thickness map."""
    brain_extraction_mask: OutputPathType
    """The brain extraction mask."""
    brain_segmentation: OutputPathType
    """The brain segmentation image."""
    segmentation_posteriors: OutputPathType
    """The segmentation posteriors for different tissue classes."""


def ants_cortical_thickness_sh(
    image_dimension: typing.Literal[2, 3],
    anatomical_image: InputPathType,
    brain_template: InputPathType,
    brain_extraction_probability_mask: InputPathType,
    brain_segmentation_priors: str,
    output_prefix: str,
    runner: Runner | None = None,
) -> AntsCorticalThicknessShOutputs:
    """
    This script performs T1 anatomical brain processing including brain extraction,
    brain n-tissue segmentation, cortical thickness estimation, and optional
    registration to a template.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: 2 or 3 for 2- or 3-dimensional image.
        anatomical_image: Structural intensity image, typically T1.
        brain_template: Anatomical intensity template. This template is not\
            skull-stripped.
        brain_extraction_probability_mask: Brain probability mask in the\
            segmentation template space. A binary mask is acceptable.
        brain_segmentation_priors: Tissue probability priors corresponding to\
            the template image specified with the -e option. At least four priors\
            must exist, corresponding to CSF, Cortical GM, WM, Subcortical GM.
        output_prefix: Output prefix for the generated filenames.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsCorticalThicknessShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_CORTICAL_THICKNESS_SH_METADATA)
    cargs = []
    cargs.append("antsCorticalThickness.sh")
    cargs.extend([
        "-d",
        str(image_dimension)
    ])
    cargs.extend([
        "-a",
        execution.input_file(anatomical_image)
    ])
    cargs.extend([
        "-e",
        execution.input_file(brain_template)
    ])
    cargs.extend([
        "-m",
        execution.input_file(brain_extraction_probability_mask)
    ])
    cargs.extend([
        "-p",
        brain_segmentation_priors
    ])
    cargs.append("[ADDITIONAL_PARAMETERS]")
    cargs.extend([
        "-o",
        output_prefix
    ])
    ret = AntsCorticalThicknessShOutputs(
        root=execution.output_file("."),
        cortical_thickness=execution.output_file(output_prefix + "CorticalThickness.nii.gz"),
        brain_extraction_mask=execution.output_file(output_prefix + "BrainExtractionMask.nii.gz"),
        brain_segmentation=execution.output_file(output_prefix + "BrainSegmentation.nii.gz"),
        segmentation_posteriors=execution.output_file(output_prefix + "BrainSegmentationPosteriors*.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_CORTICAL_THICKNESS_SH_METADATA",
    "AntsCorticalThicknessShOutputs",
    "ants_cortical_thickness_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ZEROPAD_METADATA = Metadata(
    id="69b80943bdd6b997541b13be76f096b8bce260d4.boutiques",
    name="3dZeropad",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dZeropadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_zeropad(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset_brik: OutputPathType | None
    """Output dataset (BRIK format)"""
    output_dataset_head: OutputPathType | None
    """Output dataset (HEAD format)"""


def v_3d_zeropad(
    dataset: InputPathType,
    i: float | None = None,
    s: float | None = None,
    a: float | None = None,
    p: float | None = None,
    l: float | None = None,
    r: float | None = None,
    z: float | None = None,
    rl: float | None = None,
    ap: float | None = None,
    is_: float | None = None,
    pad2even: bool = False,
    mm_flag: bool = False,
    master_dataset: InputPathType | None = None,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dZeropadOutputs:
    """
    Adds planes of zeros to a dataset (i.e., pads it out). Negative 'add' count
    means to cut a dataset down in size.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset: Input dataset.
        i: Adds 'n' planes of zero at the Inferior edge.
        s: Adds 'n' planes of zero at the Superior edge.
        a: Adds 'n' planes of zero at the Anterior edge.
        p: Adds 'n' planes of zero at the Posterior edge.
        l: Adds 'n' planes of zero at the Left edge.
        r: Adds 'n' planes of zero at the Right edge.
        z: Adds 'n' planes of zeros on EACH of the dataset z-axis\
            (slice-direction) faces.
        rl: Add/cut planes symmetrically to make the resulting volume have 'a'\
            slices in the Right/Left direction.
        ap: Add/cut planes symmetrically to make the resulting volume have 'b'\
            slices in the Anterior/Posterior direction.
        is_: Add/cut planes symmetrically to make the resulting volume have 'c'\
            slices in the Inferior/Superior direction.
        pad2even: Add 0 or 1 plane in each of the R/A/S directions, giving each\
            axis an even number of slices.
        mm_flag: Pad counts 'n' are in mm instead of slices.
        master_dataset: Match the volume described in dataset 'mset'. 'mset'\
            must have the same orientation and grid spacing as dataset to be\
            padded.
        prefix: Write result into dataset with prefix 'ppp'. Default is\
            'zeropad'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dZeropadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ZEROPAD_METADATA)
    cargs = []
    cargs.append("3dZeropad")
    cargs.append(execution.input_file(dataset))
    if i is not None:
        cargs.extend([
            "-I",
            str(i)
        ])
    if s is not None:
        cargs.extend([
            "-S",
            str(s)
        ])
    if a is not None:
        cargs.extend([
            "-A",
            str(a)
        ])
    if p is not None:
        cargs.extend([
            "-P",
            str(p)
        ])
    if l is not None:
        cargs.extend([
            "-L",
            str(l)
        ])
    if r is not None:
        cargs.extend([
            "-R",
            str(r)
        ])
    if z is not None:
        cargs.extend([
            "-z",
            str(z)
        ])
    if rl is not None:
        cargs.extend([
            "-RL",
            str(rl)
        ])
    if ap is not None:
        cargs.extend([
            "-AP",
            str(ap)
        ])
    if is_ is not None:
        cargs.extend([
            "-IS",
            str(is_)
        ])
    if pad2even:
        cargs.append("-pad2evens")
    if mm_flag:
        cargs.append("-mm")
    if master_dataset is not None:
        cargs.extend([
            "-master",
            execution.input_file(master_dataset)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    ret = V3dZeropadOutputs(
        root=execution.output_file("."),
        output_dataset_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        output_dataset_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dZeropadOutputs",
    "V_3D_ZEROPAD_METADATA",
    "v_3d_zeropad",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WFILEMASK_METADATA = Metadata(
    id="2af18e367bd17f7afc3d6c0507042e5513f946c5.boutiques",
    name="wfilemask",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class WfilemaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `wfilemask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_w_file: OutputPathType
    """Output file with specified label regions zeroed out"""


def wfilemask(
    w_file: InputPathType,
    label_file: InputPathType,
    output_file: str,
    permission_mask: str | None = None,
    help_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> WfilemaskOutputs:
    """
    Zero-out regions of a surface value file (.w file) using a label.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        w_file: Input w file.
        label_file: Label file to use as a mask.
        output_file: Output w file.
        permission_mask: Set Unix file permission mask.
        help_flag: Display help message and exit.
        version_flag: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WfilemaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WFILEMASK_METADATA)
    cargs = []
    cargs.append("wfilemask")
    cargs.extend([
        "-w",
        execution.input_file(w_file)
    ])
    cargs.extend([
        "-l",
        execution.input_file(label_file)
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    if permission_mask is not None:
        cargs.extend([
            "-umask",
            permission_mask
        ])
    if help_flag:
        cargs.append("-help")
    if version_flag:
        cargs.append("-version")
    ret = WfilemaskOutputs(
        root=execution.output_file("."),
        output_w_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WFILEMASK_METADATA",
    "WfilemaskOutputs",
    "wfilemask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_ESTIMATE_FWHM_METADATA = Metadata(
    id="5fcfc75e7e632e5ba205f400361a1c93167286ec.boutiques",
    name="volume-estimate-fwhm",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeEstimateFwhmWholeFile:
    """
    estimate for the whole file at once, not each subvolume separately.
    """
    opt_demean: bool = False
    """subtract the mean image before estimating smoothness"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-whole-file")
        if self.opt_demean:
            cargs.append("-demean")
        return cargs


class VolumeEstimateFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_estimate_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_estimate_fwhm(
    volume: InputPathType,
    opt_roi_roivol: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    whole_file: VolumeEstimateFwhmWholeFile | None = None,
    runner: Runner | None = None,
) -> VolumeEstimateFwhmOutputs:
    """
    Estimate fwhm smoothness of a volume.
    
    Estimates the smoothness of the input volume in X, Y, and Z directions
    separately, printing the estimates to standard output, in mm as FWHM. If
    -subvolume or -whole-file are not specified, each subvolume is estimated and
    displayed separately.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the input volume.
        opt_roi_roivol: use only data within an ROI: the volume to use as an\
            ROI.
        opt_subvolume_subvol: select a single subvolume to estimate smoothness\
            of: the subvolume number or name.
        whole_file: estimate for the whole file at once, not each subvolume\
            separately.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeEstimateFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_ESTIMATE_FWHM_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-estimate-fwhm")
    cargs.append(execution.input_file(volume))
    if opt_roi_roivol is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roivol)
        ])
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    if whole_file is not None:
        cargs.extend(whole_file.run(execution))
    ret = VolumeEstimateFwhmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_ESTIMATE_FWHM_METADATA",
    "VolumeEstimateFwhmOutputs",
    "VolumeEstimateFwhmWholeFile",
    "volume_estimate_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WHIRLGIF_METADATA = Metadata(
    id="e4c0871988c7cdc7bddc466fe2124de7c556f8a7.boutiques",
    name="whirlgif",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class WhirlgifOutputs(typing.NamedTuple):
    """
    Output object returned when calling `whirlgif(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_gif: OutputPathType | None
    """The output GIF file"""


def whirlgif(
    gif_files: list[InputPathType],
    verbose: bool = False,
    loop: str | None = None,
    transparency_index: float | None = None,
    inter_frame_delay: float | None = None,
    outfile: str | None = None,
    infile: InputPathType | None = None,
    runner: Runner | None = None,
) -> WhirlgifOutputs:
    """
    A quick program that reads a series of GIF files and produces a single GIF file
    composed of those images.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        gif_files: Input GIF files to be combined into a single GIF file.
        verbose: Verbose mode.
        loop: Add the Netscape 'loop' extension. Optionally specify a loop\
            count.
        transparency_index: Set the colormap index 'index' to be transparent.
        inter_frame_delay: Inter-frame timing delay.
        outfile: Specify the output file to write the results to.
        infile: Read a list of filenames from a file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WhirlgifOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WHIRLGIF_METADATA)
    cargs = []
    cargs.append("whirlgif")
    if verbose:
        cargs.append("-v")
    if loop is not None:
        cargs.extend([
            "-loop",
            loop
        ])
    if transparency_index is not None:
        cargs.extend([
            "-trans",
            str(transparency_index)
        ])
    if inter_frame_delay is not None:
        cargs.extend([
            "-time",
            str(inter_frame_delay)
        ])
    if outfile is not None:
        cargs.extend([
            "-o",
            outfile
        ])
    if infile is not None:
        cargs.extend([
            "-i",
            execution.input_file(infile)
        ])
    cargs.extend([execution.input_file(f) for f in gif_files])
    ret = WhirlgifOutputs(
        root=execution.output_file("."),
        output_gif=execution.output_file(outfile) if (outfile is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WHIRLGIF_METADATA",
    "WhirlgifOutputs",
    "whirlgif",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_FEAT2ANAT_METADATA = Metadata(
    id="6d99523d12853983a4cb41cacabf4975bd54d655.boutiques",
    name="reg-feat2anat",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RegFeat2anatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_feat2anat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    anat2std_register: OutputPathType
    """Init FS reg from anat to FSL-standard"""
    std2anat_fsl_mat: OutputPathType
    """Init FSL reg from FSL-standard to anat"""
    exf2anat_init_fsl_mat: OutputPathType
    """Init FSL reg from example_func to anat"""
    exf2anat_fsl_mat: OutputPathType
    """Final FSL reg from example_func to anat"""
    anat2exf_register: OutputPathType
    """Final FS reg from example_func to anat"""
    register_dat: OutputPathType
    """Same as anat2exf.register.dat"""
    example_func2standard_mat: OutputPathType
    """Replacement for feat-generated"""
    log_file: OutputPathType
    """Log file for registration"""


def reg_feat2anat(
    feat_dir: str,
    subject_id: str,
    overwrite_exf2std: bool = False,
    manual: bool = False,
    manxfm_type: str | None = None,
    dof: int | None = None,
    bins: int | None = None,
    cost: str | None = None,
    max_angle: float | None = None,
    bet: bool = False,
    title: str | None = None,
    no_bbr: bool = False,
    spm: bool = False,
    no_inorm: bool = False,
    fmov: str | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> RegFeat2anatOutputs:
    """
    Registers FSL-Feat example_func to FreeSurfer anatomical data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        feat_dir: Directory in which to find example_func.
        subject_id: FreeSurfer subject identifier as found in SUBJECTS_DIR.
        overwrite_exf2std: Replace Feat-generated example_func2standard.
        manual: Interactively view/edit registration.
        manxfm_type: Interactively view/edit registration for xfm type. xfmtype\
            can be: func2anat, std2anat, or func2std.
        dof: FLIRT degrees of freedom (default is 6).
        bins: FLIRT number of bins (default is 256).
        cost: FLIRT cost function (default is corratio).
        max_angle: FLIRT maximum search angle (default is 90).
        bet: Run betfunc on example_func (not with FSL 4.0).
        title: Title for tkregister window.
        no_bbr: Do not use boundary-based registration.
        spm: Use SPM instead of FLIRT, 6 dof only.
        no_inorm: Do not inorm when running tkregister2.
        fmov: fmov argument for tkregister2.
        debug: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegFeat2anatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_FEAT2ANAT_METADATA)
    cargs = []
    cargs.append("reg-feat2anat")
    cargs.extend([
        "--feat",
        feat_dir
    ])
    cargs.extend([
        "--subject",
        subject_id
    ])
    if overwrite_exf2std:
        cargs.append("--overwrite-exf2std")
    if manual:
        cargs.append("--manual")
    if manxfm_type is not None:
        cargs.extend([
            "--manxfm",
            manxfm_type
        ])
    if dof is not None:
        cargs.extend([
            "--dof",
            str(dof)
        ])
    if bins is not None:
        cargs.extend([
            "--bins",
            str(bins)
        ])
    if cost is not None:
        cargs.extend([
            "--cost",
            cost
        ])
    if max_angle is not None:
        cargs.extend([
            "--maxangle",
            str(max_angle)
        ])
    if bet:
        cargs.append("--bet")
    if title is not None:
        cargs.extend([
            "--title",
            title
        ])
    if no_bbr:
        cargs.append("--no-bbr")
    if spm:
        cargs.append("--spm")
    if no_inorm:
        cargs.append("--no-inorm")
    if fmov is not None:
        cargs.extend([
            "--fmov",
            fmov
        ])
    if debug:
        cargs.append("--debug")
    ret = RegFeat2anatOutputs(
        root=execution.output_file("."),
        anat2std_register=execution.output_file("featdir/reg/freesurfer/anat2std.register.dat"),
        std2anat_fsl_mat=execution.output_file("featdir/reg/freesurfer/std2anat.fsl.mat"),
        exf2anat_init_fsl_mat=execution.output_file("featdir/reg/freesurfer/exf2anat.init.fsl.mat"),
        exf2anat_fsl_mat=execution.output_file("featdir/reg/freesurfer/exf2anat.fsl.mat"),
        anat2exf_register=execution.output_file("featdir/reg/freesurfer/anat2exf.register.dat"),
        register_dat=execution.output_file("featdir/reg/freesurfer/register.dat"),
        example_func2standard_mat=execution.output_file("featdir/reg/freesurfer/example_func2standard.mat"),
        log_file=execution.output_file("reg/freesurfer/reg-feat2anat.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_FEAT2ANAT_METADATA",
    "RegFeat2anatOutputs",
    "reg_feat2anat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_CREATE_ORIG_METADATA = Metadata(
    id="90b8f21bd10e8814ce52ca803641ec5d4e3eb057.boutiques",
    name="long_create_orig",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongCreateOrigOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_create_orig(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_directory: OutputPathType
    """Output directory for processed time point data. Defaults to the specified
    path."""


def long_create_orig(
    base_id: str,
    tp_id: str | None = None,
    runner: Runner | None = None,
) -> LongCreateOrigOutputs:
    """
    Maps, conforms and averages (motioncorrect) raw inputs from cross-sectional
    directory to base space in Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        base_id: Base ID to be utilized in the process.
        tp_id: Time point ID. If omitted, operates on all time points in base.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongCreateOrigOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_CREATE_ORIG_METADATA)
    cargs = []
    cargs.append("long_create_orig")
    cargs.append(base_id)
    if tp_id is not None:
        cargs.append(tp_id)
    ret = LongCreateOrigOutputs(
        root=execution.output_file("."),
        output_directory=execution.output_file("<SUBJECTS_DIR>/<base-id>/longtp/<tp-id>"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_CREATE_ORIG_METADATA",
    "LongCreateOrigOutputs",
    "long_create_orig",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_MULTIVARIATE_TEMPLATE_CONSTRUCTION2_SH_METADATA = Metadata(
    id="b866ae2f76511eca887345fe0515e30b2318f31e.boutiques",
    name="antsMultivariateTemplateConstruction2.sh",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsMultivariateTemplateConstruction2ShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_multivariate_template_construction2_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    template: OutputPathType
    """The output multivariate template."""


def ants_multivariate_template_construction2_sh(
    input_: str,
    runner: Runner | None = None,
) -> AntsMultivariateTemplateConstruction2ShOutputs:
    """
    The antsMultivariateTemplateConstruction2.sh script is part of the Advanced
    Normalization Tools (ANTs) suite. It is used for constructing multivariate
    templates.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_: Options for setting up and running the multivariate template\
            construction process.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsMultivariateTemplateConstruction2ShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_MULTIVARIATE_TEMPLATE_CONSTRUCTION2_SH_METADATA)
    cargs = []
    cargs.append("antsMultivariateTemplateConstruction2.sh")
    cargs.append(input_)
    ret = AntsMultivariateTemplateConstruction2ShOutputs(
        root=execution.output_file("."),
        template=execution.output_file("<output-prefix>Template.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_MULTIVARIATE_TEMPLATE_CONSTRUCTION2_SH_METADATA",
    "AntsMultivariateTemplateConstruction2ShOutputs",
    "ants_multivariate_template_construction2_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIX_SUBJECT_METADATA = Metadata(
    id="61bfaf4767ebcb038e8eec8be58f3650a3ee7f43.boutiques",
    name="fix_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FixSubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fix_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fix_subject(
    arguments: str | None = None,
    runner: Runner | None = None,
) -> FixSubjectOutputs:
    """
    Tool to fix subjects in FreeSurfer, encountered errors due to incorrect path
    handling.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        arguments: Arguments for fix_subject command. Currently, help output\
            shows directory errors. Ensure the correct paths are used.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FixSubjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIX_SUBJECT_METADATA)
    cargs = []
    cargs.append("fix_subject")
    if arguments is not None:
        cargs.append(arguments)
    ret = FixSubjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIX_SUBJECT_METADATA",
    "FixSubjectOutputs",
    "fix_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_NL_ALIGN_METADATA = Metadata(
    id="cd2a19b23e2fec00175500358afe679cc9ee7fc7.boutiques",
    name="mri_nl_align",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriNlAlignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_nl_align(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    warp_output: OutputPathType
    """Resulting warp output file after alignment"""


def mri_nl_align(
    source: InputPathType,
    target: InputPathType,
    warp: str,
    debug_voxel: list[float] | None = None,
    debug_node: list[float] | None = None,
    no_neg: float | None = None,
    renormalize: float | None = None,
    aseg_flag: bool = False,
    diag_volume: str | None = None,
    optimal_flag: bool = False,
    momentum_flag: bool = False,
    fixed_flag: bool = False,
    distance: float | None = None,
    dtrans: float | None = None,
    match_peak_flag: bool = False,
    erode: float | None = None,
    match_mean: float | None = None,
    intensity: float | None = None,
    noregrid_flag: bool = False,
    regrid_flag: bool = False,
    view: list[float] | None = None,
    levels: float | None = None,
    area_smoothness: float | None = None,
    area: float | None = None,
    tolerance: float | None = None,
    sigma: float | None = None,
    min_sigma: float | None = None,
    ribbon: InputPathType | None = None,
    rthresh: float | None = None,
    scale: float | None = None,
    dt: float | None = None,
    passes: float | None = None,
    skip: float | None = None,
    apply: float | None = None,
    distance_log: float | None = None,
    momentum: float | None = None,
    iterations: float | None = None,
    smoothness: float | None = None,
    transform: InputPathType | None = None,
    inverse_transform: InputPathType | None = None,
    binary: float | None = None,
    jacobian: float | None = None,
    disable_zero_locations: float | None = None,
    smooth_averages: float | None = None,
    exp_k: float | None = None,
    diagnostics: float | None = None,
    runner: Runner | None = None,
) -> MriNlAlignOutputs:
    """
    mri_nl_align aligns two images using nonlinear registration.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source: Input source image file.
        target: Input target image file.
        warp: Output warp file.
        debug_voxel: Debug voxel coordinates (Gx, Gy, Gz).
        debug_node: Debug node coordinates (Gx, Gy, Gz).
        no_neg: Control allowing temporary folds during numerical minimization.
        renormalize: Control for renormalizing intensities.
        aseg_flag: Treat inputs as segmentations.
        diag_volume: Write d2 diagnostics for input volume.
        optimal_flag: Use line search optimization.
        momentum_flag: Use fixed time-step integration.
        fixed_flag: Use fixed time-step integration.
        distance: Expand border by specified mm every outer cycle.
        dtrans: Set distance transform coefficient.
        match_peak_flag: Match peak of intensity ratio histogram.
        erode: Erode source and target image specified times before morphing.
        match_mean: Control for matching peak of intensity ratio histogram.
        intensity: Set l_log_likelihood to specified value.
        noregrid_flag: Disable regridding.
        regrid_flag: Enable regridding.
        view: View voxel coordinates (Gx, Gy, Gz).
        levels: Set levels to specified value.
        area_smoothness: Set l_area_smoothness to specified value.
        area: Set l_area to specified value.
        tolerance: Set tolerance to specified value.
        sigma: Set sigma to specified value.
        min_sigma: Set minimum sigma value.
        ribbon: Read ribbon from specified file and insert into aseg.
        rthresh: Set compression ratio threshold to specified value.
        scale: Scale input values by specified factor.
        dt: Set dt to specified value.
        passes: Integrate in specified number of passes.
        skip: Skip specified number of voxels in source data.
        apply: Control for applying transform after registration.
        distance_log: Set l_distance to specified value.
        momentum: Set momentum to specified value.
        iterations: Set number of iterations to specified value.
        smoothness: Set l_smoothness to specified value.
        transform: Read the forward transform from specified file.
        inverse_transform: Read the inverse transform from specified file.
        binary: Set l_binary to specified value.
        jacobian: Set l_jacobian to specified value.
        disable_zero_locations: Control for disabling zero image locations.
        smooth_averages: Smooth gradient with specified number of averages.
        exp_k: Set exp_k to specified value.
        diagnostics: Write diagnostics at each specified iteration.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriNlAlignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_NL_ALIGN_METADATA)
    cargs = []
    cargs.append("mri_nl_align")
    cargs.append(execution.input_file(source))
    cargs.append(execution.input_file(target))
    cargs.append(warp)
    if debug_voxel is not None:
        cargs.extend([
            "-debug_voxel",
            *map(str, debug_voxel)
        ])
    if debug_node is not None:
        cargs.extend([
            "-debug_node",
            *map(str, debug_node)
        ])
    if no_neg is not None:
        cargs.extend([
            "-noneg",
            str(no_neg)
        ])
    if renormalize is not None:
        cargs.extend([
            "-renormalize",
            str(renormalize)
        ])
    if aseg_flag:
        cargs.append("-aseg")
    if diag_volume is not None:
        cargs.extend([
            "-diag2",
            diag_volume
        ])
    if optimal_flag:
        cargs.append("-OPTIMAL")
    if momentum_flag:
        cargs.append("-MOMENTUM")
    if fixed_flag:
        cargs.append("-FIXED")
    if distance is not None:
        cargs.extend([
            "-distance",
            str(distance)
        ])
    if dtrans is not None:
        cargs.extend([
            "-dtrans",
            str(dtrans)
        ])
    if match_peak_flag:
        cargs.append("-match_peak")
    if erode is not None:
        cargs.extend([
            "-erode",
            str(erode)
        ])
    if match_mean is not None:
        cargs.extend([
            "-match_mean",
            str(match_mean)
        ])
    if intensity is not None:
        cargs.extend([
            "-intensity",
            str(intensity)
        ])
    if noregrid_flag:
        cargs.append("-noregrid")
    if regrid_flag:
        cargs.append("-regrid")
    if view is not None:
        cargs.extend([
            "-view",
            *map(str, view)
        ])
    if levels is not None:
        cargs.extend([
            "-levels",
            str(levels)
        ])
    if area_smoothness is not None:
        cargs.extend([
            "-areasmoothness",
            str(area_smoothness)
        ])
    if area is not None:
        cargs.extend([
            "-area",
            str(area)
        ])
    if tolerance is not None:
        cargs.extend([
            "-tol",
            str(tolerance)
        ])
    if sigma is not None:
        cargs.extend([
            "-sigma",
            str(sigma)
        ])
    if min_sigma is not None:
        cargs.extend([
            "-min_sigma",
            str(min_sigma)
        ])
    if ribbon is not None:
        cargs.extend([
            "-ribbon",
            execution.input_file(ribbon)
        ])
    if rthresh is not None:
        cargs.extend([
            "-rthresh",
            str(rthresh)
        ])
    if scale is not None:
        cargs.extend([
            "-scale",
            str(scale)
        ])
    if dt is not None:
        cargs.extend([
            "-dt",
            str(dt)
        ])
    if passes is not None:
        cargs.extend([
            "-passes",
            str(passes)
        ])
    if skip is not None:
        cargs.extend([
            "-skip",
            str(skip)
        ])
    if apply is not None:
        cargs.extend([
            "-apply",
            str(apply)
        ])
    if distance_log is not None:
        cargs.extend([
            "-D",
            str(distance_log)
        ])
    if momentum is not None:
        cargs.extend([
            "-M",
            str(momentum)
        ])
    if iterations is not None:
        cargs.extend([
            "-N",
            str(iterations)
        ])
    if smoothness is not None:
        cargs.extend([
            "-s",
            str(smoothness)
        ])
    if transform is not None:
        cargs.extend([
            "-T",
            execution.input_file(transform)
        ])
    if inverse_transform is not None:
        cargs.extend([
            "-I",
            execution.input_file(inverse_transform)
        ])
    if binary is not None:
        cargs.extend([
            "-B",
            str(binary)
        ])
    if jacobian is not None:
        cargs.extend([
            "-J",
            str(jacobian)
        ])
    if disable_zero_locations is not None:
        cargs.extend([
            "-Z",
            str(disable_zero_locations)
        ])
    if smooth_averages is not None:
        cargs.extend([
            "-a",
            str(smooth_averages)
        ])
    if exp_k is not None:
        cargs.extend([
            "-K",
            str(exp_k)
        ])
    if diagnostics is not None:
        cargs.extend([
            "-W",
            str(diagnostics)
        ])
    ret = MriNlAlignOutputs(
        root=execution.output_file("."),
        warp_output=execution.output_file(warp),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_NL_ALIGN_METADATA",
    "MriNlAlignOutputs",
    "mri_nl_align",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_VIOLIN_PLOTS_METADATA = Metadata(
    id="a193f3c5d1fcce153b59c31f2df32aafdf44cb45.boutiques",
    name="dmri_violinPlots",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriViolinPlotsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_violin_plots(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_violin_plots(
    input_directory: str,
    labels: InputPathType,
    structure: str,
    runner: Runner | None = None,
) -> DmriViolinPlotsOutputs:
    """
    Generate violin plots for dMRI data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_directory: Directory with all subjects.
        labels: CSV file with group labels.
        structure: Name of the structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriViolinPlotsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_VIOLIN_PLOTS_METADATA)
    cargs = []
    cargs.append("dmri_violinPlots")
    cargs.extend([
        "-i",
        input_directory
    ])
    cargs.extend([
        "-l",
        execution.input_file(labels)
    ])
    cargs.extend([
        "-s",
        structure
    ])
    ret = DmriViolinPlotsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_VIOLIN_PLOTS_METADATA",
    "DmriViolinPlotsOutputs",
    "dmri_violin_plots",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MAP_CPDAT_METADATA = Metadata(
    id="0c1d6881dadae3c5b917be778e2808a99602f9d0.boutiques",
    name="mri_map_cpdat",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMapCpdatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_map_cpdat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_ctrl_file: OutputPathType
    """Output control point text file"""


def mri_map_cpdat(
    input_file: InputPathType,
    output_file: str,
    lta_file: InputPathType | None = None,
    to_mni305: str | None = None,
    from_mni305: str | None = None,
    subject_list_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriMapCpdatOutputs:
    """
    Maps a control.dat file to a different space using an LTA.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input control point text file.
        output_file: Output control point text file.
        lta_file: LTA transform file to be applied.
        to_mni305: Get LTA from talairach.xfm for a specific subject.
        from_mni305: Get LTA from talairach.xfm from a specific subject.
        subject_list_file: Maps all control points from all subjects listed in\
            the text/ascii subjectlistfile to MNI305 (talairach) space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMapCpdatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MAP_CPDAT_METADATA)
    cargs = []
    cargs.append("mri_map_cpdat")
    cargs.extend([
        "-in",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-out",
        output_file
    ])
    if lta_file is not None:
        cargs.extend([
            "-lta",
            execution.input_file(lta_file)
        ])
    if to_mni305 is not None:
        cargs.extend([
            "-tomni305",
            to_mni305
        ])
    if from_mni305 is not None:
        cargs.extend([
            "-frommni305",
            from_mni305
        ])
    if subject_list_file is not None:
        cargs.extend([
            "-slf",
            execution.input_file(subject_list_file)
        ])
    ret = MriMapCpdatOutputs(
        root=execution.output_file("."),
        output_ctrl_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MAP_CPDAT_METADATA",
    "MriMapCpdatOutputs",
    "mri_map_cpdat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_RIGID_REGISTER_METADATA = Metadata(
    id="3a621587bc05ee701fd4feb941dda84ba58c25da.boutiques",
    name="mri_rigid_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriRigidRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_rigid_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transform_file: OutputPathType
    """Output file for transform matrix"""


def mri_rigid_register(
    source_volume: InputPathType,
    target_volume: InputPathType,
    transform_output: str,
    runner: Runner | None = None,
) -> MriRigidRegisterOutputs:
    """
    Rigid registration tool for MRI volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source_volume: Source volume file for registration.
        target_volume: Target volume file for registration.
        transform_output: Output file name for the transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriRigidRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_RIGID_REGISTER_METADATA)
    cargs = []
    cargs.append("mri_rigid_register")
    cargs.append(execution.input_file(source_volume))
    cargs.append(execution.input_file(target_volume))
    cargs.append(transform_output)
    ret = MriRigidRegisterOutputs(
        root=execution.output_file("."),
        transform_file=execution.output_file(transform_output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_RIGID_REGISTER_METADATA",
    "MriRigidRegisterOutputs",
    "mri_rigid_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__COMPUTE_GCOR_METADATA = Metadata(
    id="7c21653eea6abdf613e32c0ba0461541cf95e2ae.boutiques",
    name="@compute_gcor",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VComputeGcorOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__compute_gcor(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corr_vol_brik: OutputPathType | None
    """Output correlation volume BRIK file"""
    corr_vol_head: OutputPathType | None
    """Output correlation volume HEAD file"""


def v__compute_gcor(
    input_: InputPathType,
    mask: InputPathType | None = None,
    corr_vol_prefix: str | None = None,
    initial_trs: float | None = None,
    no_demean: bool = False,
    save_tmp: bool = False,
    verbose: float | None = None,
    runner: Runner | None = None,
) -> VComputeGcorOutputs:
    """
    Compute GCOR, the global correlation.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Specify input dataset to compute the GCOR over.
        mask: Specify mask dataset, for restricting the computation.
        corr_vol_prefix: Specify prefix for correlation volume output.
        initial_trs: Specify number of initial TRs to ignore.
        no_demean: Do not demean as the first step.
        save_tmp: Save temporary files (do not remove at end).
        verbose: Set verbose level (0=quiet, 3=max).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VComputeGcorOutputs`).
    """
    if verbose is not None and not (0 <= verbose <= 3): 
        raise ValueError(f"'verbose' must be between 0 <= x <= 3 but was {verbose}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__COMPUTE_GCOR_METADATA)
    cargs = []
    cargs.append("@compute_gcor")
    cargs.append(execution.input_file(input_))
    if mask is not None:
        cargs.append(execution.input_file(mask))
    if corr_vol_prefix is not None:
        cargs.extend([
            "-corr_vol",
            corr_vol_prefix
        ])
    if initial_trs is not None:
        cargs.extend([
            "-nfirst",
            str(initial_trs)
        ])
    if no_demean:
        cargs.append("-no_demean")
    if save_tmp:
        cargs.append("-savetmp")
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    ret = VComputeGcorOutputs(
        root=execution.output_file("."),
        corr_vol_brik=execution.output_file(corr_vol_prefix + "+tlrc.BRIK") if (corr_vol_prefix is not None) else None,
        corr_vol_head=execution.output_file(corr_vol_prefix + "+tlrc.HEAD") if (corr_vol_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VComputeGcorOutputs",
    "V__COMPUTE_GCOR_METADATA",
    "v__compute_gcor",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FWHM_METADATA = Metadata(
    id="d03adb51c2f77acaf364735a5ea7ff81b4be91ea.boutiques",
    name="mri_fwhm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume_file: OutputPathType
    """Output volume after smoothing."""
    final_mask_output_file: OutputPathType | None
    """Final mask volume."""
    summary_log_file: OutputPathType | None
    """Summary log file."""
    final_fwhm_estimate_file: OutputPathType | None
    """Final FWHM estimate file."""
    fwhm_of_each_dimension_file: OutputPathType | None
    """File containing the FWHM of each dimension."""
    mean_fwhm_volume_file: OutputPathType | None
    """Mean FWHM from volume file."""
    fwhm_volume_file: OutputPathType | None
    """FWHM volume file."""


def mri_fwhm(
    inputvol: InputPathType,
    outputvol: str,
    save_detrended: bool = False,
    save_unmasked: bool = False,
    smooth_only: bool = False,
    mask: InputPathType | None = None,
    mask_thresh: float | None = None,
    auto_mask: float | None = None,
    nerode: float | None = None,
    mask_inv: bool = False,
    out_mask: str | None = None,
    detrend_matrix: InputPathType | None = None,
    detrend_order: float | None = None,
    square_input: bool = False,
    smooth_by_fwhm: float | None = None,
    smooth_by_gstd: float | None = None,
    median_filter: float | None = None,
    smooth_to_fwhm: float | None = None,
    to_fwhm_tol: float | None = None,
    to_fwhm_nmax: float | None = None,
    to_fwhm_file: str | None = None,
    summary_file: str | None = None,
    dat_file: str | None = None,
    fwhm_dat_file: str | None = None,
    fwhm_vol_mean_file: str | None = None,
    fwhm_vol: str | None = None,
    synth: bool = False,
    synth_frames: float | None = None,
    nframes_min: float | None = None,
    ispm: bool = False,
    nspm_zero_padding: float | None = None,
    threads: float | None = None,
    debug: bool = False,
    checkopts: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriFwhmOutputs:
    """
    FreeSurfer program to estimate the global Gaussian smoothness of a multi-frame,
    volume-based data set.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        inputvol: Input volume file. Format must be something readable by\
            mri_convert (e.g., mgh, mgz, img, nii, nii.gz).
        outputvol: Output volume file: save input after smoothing.
        save_detrended: Save input after smoothing and detrending.
        save_unmasked: Do not mask output volume.
        smooth_only: Smooth and save, do not compute fwhm.
        mask: Binary mask file.
        mask_thresh: Threshold for mask (default is 0.5).
        auto_mask: Auto compute mask based on global mean threshold.
        nerode: Erode mask n times prior to FWHM computation.
        mask_inv: Invert mask.
        out_mask: Save final mask to outmaskvol.
        detrend_matrix: Detrending matrix file in MATLAB4 format.
        detrend_order: Polynomial detrending order (default 0).
        square_input: Compute square of input before smoothing.
        smooth_by_fwhm: Smooth BY fwhm before measuring.
        smooth_by_gstd: Smooth using gstd (equivalent to --fwhm).
        median_filter: Perform median filtering instead of Gaussian.
        smooth_to_fwhm: Smooth TO this FWHM.
        to_fwhm_tol: Tolerance for smoothing to FWHM (default 0.5mm).
        to_fwhm_nmax: Maximum iterations for smoothing to FWHM (default 20).
        to_fwhm_file: Save smoothing to FWHM parameters to file.
        summary_file: Summary/log file.
        dat_file: Prints only the final FWHM estimate into this file.
        fwhm_dat_file: Compute and save the FWHM of each dimension.
        fwhm_vol_mean_file: Compute and save the FWHM of each dimension based\
            on fwhmvol.
        fwhm_vol: Save FWHM volume.
        synth: Synthesize input with white Gaussian noise.
        synth_frames: Number of frames for synthesized input (default is 10).
        nframes_min: Require at least this many frames.
        ispm: Input is SPM-analyze.
        nspm_zero_padding: Zero-padding for SPM-analyze.
        threads: Set OPEN MP threads.
        debug: Turn on debugging.
        checkopts: Check options and exit without running.
        version: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FWHM_METADATA)
    cargs = []
    cargs.append("mri_fwhm")
    cargs.extend([
        "--i",
        execution.input_file(inputvol)
    ])
    cargs.extend([
        "--o",
        outputvol
    ])
    if save_detrended:
        cargs.append("--save-detrended")
    if save_unmasked:
        cargs.append("--save-unmasked")
    if smooth_only:
        cargs.append("--smooth-only")
    if mask is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask)
        ])
    if mask_thresh is not None:
        cargs.extend([
            "--mask-thresh",
            str(mask_thresh)
        ])
    if auto_mask is not None:
        cargs.extend([
            "--auto-mask",
            str(auto_mask)
        ])
    if nerode is not None:
        cargs.extend([
            "--nerode",
            str(nerode)
        ])
    if mask_inv:
        cargs.append("--mask-inv")
    if out_mask is not None:
        cargs.extend([
            "--out-mask",
            out_mask
        ])
    if detrend_matrix is not None:
        cargs.extend([
            "--X",
            execution.input_file(detrend_matrix)
        ])
    if detrend_order is not None:
        cargs.extend([
            "--detrend",
            str(detrend_order)
        ])
    if square_input:
        cargs.append("--sqr")
    if smooth_by_fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(smooth_by_fwhm)
        ])
    if smooth_by_gstd is not None:
        cargs.extend([
            "--gstd",
            str(smooth_by_gstd)
        ])
    if median_filter is not None:
        cargs.extend([
            "--median",
            str(median_filter)
        ])
    if smooth_to_fwhm is not None:
        cargs.extend([
            "--to-fwhm",
            str(smooth_to_fwhm)
        ])
    if to_fwhm_tol is not None:
        cargs.extend([
            "--to-fwhm-tol",
            str(to_fwhm_tol)
        ])
    if to_fwhm_nmax is not None:
        cargs.extend([
            "--to-fwhm-nmax",
            str(to_fwhm_nmax)
        ])
    if to_fwhm_file is not None:
        cargs.extend([
            "--to-fwhm-file",
            to_fwhm_file
        ])
    if summary_file is not None:
        cargs.extend([
            "--sum",
            summary_file
        ])
    if dat_file is not None:
        cargs.extend([
            "--dat",
            dat_file
        ])
    if fwhm_dat_file is not None:
        cargs.extend([
            "--fwhmdat",
            fwhm_dat_file
        ])
    if fwhm_vol_mean_file is not None:
        cargs.extend([
            "--fwhmvolmn",
            fwhm_vol_mean_file
        ])
    if fwhm_vol is not None:
        cargs.extend([
            "--fwhmvol",
            fwhm_vol
        ])
    if synth:
        cargs.append("--synth")
    if synth_frames is not None:
        cargs.extend([
            "--synth-frames",
            str(synth_frames)
        ])
    if nframes_min is not None:
        cargs.extend([
            "--nframesmin",
            str(nframes_min)
        ])
    if ispm:
        cargs.append("--ispm")
    if nspm_zero_padding is not None:
        cargs.extend([
            "--in_nspmzeropad",
            str(nspm_zero_padding)
        ])
    if threads is not None:
        cargs.extend([
            "--nthreads",
            str(threads)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if version:
        cargs.append("--version")
    ret = MriFwhmOutputs(
        root=execution.output_file("."),
        output_volume_file=execution.output_file(outputvol),
        final_mask_output_file=execution.output_file(out_mask) if (out_mask is not None) else None,
        summary_log_file=execution.output_file(summary_file) if (summary_file is not None) else None,
        final_fwhm_estimate_file=execution.output_file(dat_file) if (dat_file is not None) else None,
        fwhm_of_each_dimension_file=execution.output_file(fwhm_dat_file) if (fwhm_dat_file is not None) else None,
        mean_fwhm_volume_file=execution.output_file(fwhm_vol_mean_file) if (fwhm_vol_mean_file is not None) else None,
        fwhm_volume_file=execution.output_file(fwhm_vol) if (fwhm_vol is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FWHM_METADATA",
    "MriFwhmOutputs",
    "mri_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SMOOTH_INTRACORTICAL_METADATA = Metadata(
    id="2d913141d3a964703c9f9e1365f71235771f5c17.boutiques",
    name="mris_smooth_intracortical",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSmoothIntracorticalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_smooth_intracortical(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_overlay: OutputPathType | None
    """Output overlay file."""


def mris_smooth_intracortical(
    surf_dir: str,
    surf_name: str,
    overlay_dir: str,
    overlay_name: str,
    output_dir: str | None = "[OVERLAY_DIR]",
    output_name: str | None = None,
    tan_size: int | None = None,
    rad_size: float | None = None,
    rad_start: float | None = None,
    tan_weights: str | None = None,
    runner: Runner | None = None,
) -> MrisSmoothIntracorticalOutputs:
    """
    Smooths data overlaid onto cortical surface meshes using specified tangential
    and radial extents.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surf_dir: Directory with surface meshes.
        surf_name: Name of a surface file(s). Use * and ? to pass multiple\
            names (max 20).
        overlay_dir: Directory with surface mesh overlays.
        overlay_name: Name of an overlay file(s). Use * and ? to pass multiple\
            names (max 20).
        output_dir: Path to the output directory. Default is same as overlay\
            directory.
        output_name: Name of the output overlay file.
        tan_size: Tangential extent of the smoothing kernel. Default = 0, Max =\
            6.
        rad_size: Radial extent of the intracortical smoothing kernel.
        rad_start: Starting surface mesh of the intracortical smoothing kernel\
            in the radial direction.
        tan_weights: Weighting function for tangential smoothing. 'gauss' or\
            'distance'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSmoothIntracorticalOutputs`).
    """
    if tan_size is not None and not (0 <= tan_size <= 6): 
        raise ValueError(f"'tan_size' must be between 0 <= x <= 6 but was {tan_size}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SMOOTH_INTRACORTICAL_METADATA)
    cargs = []
    cargs.append("mris_smooth_intracortical")
    cargs.extend([
        "--surf_dir",
        surf_dir
    ])
    cargs.extend([
        "--surf_name",
        surf_name
    ])
    cargs.extend([
        "--overlay_dir",
        overlay_dir
    ])
    cargs.extend([
        "--overlay_name",
        overlay_name
    ])
    if output_dir is not None:
        cargs.extend([
            "--output_dir",
            "[" + output_dir + "]"
        ])
    if output_name is not None:
        cargs.extend([
            "--output_name",
            "[" + output_name + "]"
        ])
    if tan_size is not None:
        cargs.extend([
            "--tan-size",
            "[" + str(tan_size) + "]"
        ])
    if rad_size is not None:
        cargs.extend([
            "--rad-size",
            "[" + str(rad_size) + "]"
        ])
    if rad_start is not None:
        cargs.extend([
            "--rad-start",
            "[" + str(rad_start) + "]"
        ])
    if tan_weights is not None:
        cargs.extend([
            "--tan-weights",
            "[" + tan_weights + "]"
        ])
    ret = MrisSmoothIntracorticalOutputs(
        root=execution.output_file("."),
        output_overlay=execution.output_file(output_dir + "/" + output_name) if (output_dir is not None and output_name is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SMOOTH_INTRACORTICAL_METADATA",
    "MrisSmoothIntracorticalOutputs",
    "mris_smooth_intracortical",
]
